@@ -207,6 +207,7 @@ static FieldInfo field_infos[] = {
     [MMC_F_BEARER_PROPERTIES_APN]             = { "bearer.properties.apn",                           "apn",                      MMC_S_BEARER_PROPERTIES,       },
     [MMC_F_BEARER_PROPERTIES_ROAMING]         = { "bearer.properties.roaming",                       "roaming",                  MMC_S_BEARER_PROPERTIES,       },
     [MMC_F_BEARER_PROPERTIES_IP_TYPE]         = { "bearer.properties.ip-type",                       "ip type",                  MMC_S_BEARER_PROPERTIES,       },
+    [MMC_F_BEARER_PROPERTIES_ALLOWED_AUTH]    = { "bearer.properties.allowed-auth",                  "allowed-auth",             MMC_S_BEARER_PROPERTIES,       },
     [MMC_F_BEARER_PROPERTIES_USER]            = { "bearer.properties.user",                          "user",                     MMC_S_BEARER_PROPERTIES,       },
     [MMC_F_BEARER_PROPERTIES_PASSWORD]        = { "bearer.properties.password",                      "password",                 MMC_S_BEARER_PROPERTIES,       },
     [MMC_F_BEARER_PROPERTIES_NUMBER]          = { "bearer.properties.number",                        "number",                   MMC_S_BEARER_PROPERTIES,       },
@@ -226,6 +227,11 @@ static FieldInfo field_infos[] = {
     [MMC_F_BEARER_STATS_DURATION]             = { "bearer.stats.duration",                           "duration",                 MMC_S_BEARER_STATS,            },
     [MMC_F_BEARER_STATS_BYTES_RX]             = { "bearer.stats.bytes-rx",                           "bytes rx",                 MMC_S_BEARER_STATS,            },
     [MMC_F_BEARER_STATS_BYTES_TX]             = { "bearer.stats.bytes-tx",                           "bytes tx",                 MMC_S_BEARER_STATS,            },
+    [MMC_F_BEARER_STATS_ATTEMPTS]             = { "bearer.stats.attempts",                           "attempts",                 MMC_S_BEARER_STATS,            },
+    [MMC_F_BEARER_STATS_FAILED_ATTEMPTS]      = { "bearer.stats.failed-attempts",                    "attempts",                 MMC_S_BEARER_STATS,            },
+    [MMC_F_BEARER_STATS_TOTAL_DURATION]       = { "bearer.stats.total-duration",                     "total-duration",           MMC_S_BEARER_STATS,            },
+    [MMC_F_BEARER_STATS_TOTAL_BYTES_RX]       = { "bearer.stats.total-bytes-rx",                     "total-bytes rx",           MMC_S_BEARER_STATS,            },
+    [MMC_F_BEARER_STATS_TOTAL_BYTES_TX]       = { "bearer.stats.total-bytes-tx",                     "total-bytes tx",           MMC_S_BEARER_STATS,            },
     [MMC_F_CALL_GENERAL_DBUS_PATH]            = { "call.dbus-path",                                  "dbus path",                MMC_S_CALL_GENERAL,            },
     [MMC_F_CALL_PROPERTIES_NUMBER]            = { "call.properties.number",                          "number",                   MMC_S_CALL_PROPERTIES,         },
     [MMC_F_CALL_PROPERTIES_DIRECTION]         = { "call.properties.direction",                       "direction",                MMC_S_CALL_PROPERTIES,         },
@@ -332,6 +338,8 @@ output_item_free (OutputItem *item)
             g_free (((OutputItemListitem *)item)->value);
             g_free (((OutputItemListitem *)item)->extra);
             break;
+        default:
+            g_assert_not_reached ();
     }
 }
 
@@ -1079,6 +1087,49 @@ dump_output_list_keyvalue (MmcF field)
 /******************************************************************************/
 /* JSON-friendly output */
 
+static gchar *
+json_strescape (const gchar *str)
+{
+    const gchar *p;
+    const gchar *end;
+    GString *output;
+    gsize len;
+
+    len = strlen (str);
+    end = str + len;
+    output = g_string_sized_new (len);
+
+    for (p = str; p < end; p++) {
+        if (*p == '\\' || *p == '"') {
+            g_string_append_c (output, '\\');
+            g_string_append_c (output, *p);
+        } else if ((*p > 0 && *p < 0x1f) || *p == 0x7f) {
+            switch (*p) {
+                case '\b':
+                    g_string_append (output, "\\b");
+                    break;
+                case '\f':
+                    g_string_append (output, "\\f");
+                    break;
+                case '\n':
+                    g_string_append (output, "\\n");
+                    break;
+                case '\r':
+                    g_string_append (output, "\\r");
+                    break;
+                case '\t':
+                    g_string_append (output, "\\t");
+                    break;
+                default:
+                    g_string_append_printf (output, "\\u00%02x", (guint)*p);
+                    break;
+            }
+        } else
+            g_string_append_c (output, *p);
+    }
+    return g_string_free (output, FALSE);
+}
+
 static gint
 list_sort_by_keys (const OutputItem *item_a,
                    const OutputItem *item_b)
@@ -1138,7 +1189,7 @@ dump_output_json (void)
             gchar            *escaped = NULL;
 
             if (single->value)
-                escaped = g_strescape (single->value, "\v");
+                escaped = json_strescape (single->value);
 
             g_print ("\"%s\":\"%s\"", current_path[cur_dlen], escaped ? escaped : "--");
             g_free (escaped);
@@ -1152,7 +1203,7 @@ dump_output_json (void)
             for (i = 0; i < n; i++) {
                 gchar *escaped;
 
-                escaped = g_strescape (multiple->values[i], "\v");
+                escaped = json_strescape (multiple->values[i]);
                 g_print("\"%s\"", escaped);
                 if (i < n - 1)
                     g_print(",");
@@ -1217,6 +1268,8 @@ mmcli_output_dump (void)
     case MMC_OUTPUT_TYPE_JSON:
         dump_output_json ();
         break;
+    default:
+        g_assert_not_reached ();
     }
 
     g_list_free_full (output_items, (GDestroyNotify) output_item_free);
@@ -1240,6 +1293,8 @@ mmcli_output_list_dump (MmcF field)
     case MMC_OUTPUT_TYPE_JSON:
         dump_output_list_json (field);
         break;
+    default:
+        g_assert_not_reached ();
     }
 
     g_list_free_full (output_items, (GDestroyNotify) output_item_free);
