@@ -224,6 +224,7 @@ typedef enum {
     MMC_F_BEARER_PROPERTIES_APN,
     MMC_F_BEARER_PROPERTIES_ROAMING,
     MMC_F_BEARER_PROPERTIES_IP_TYPE,
+    MMC_F_BEARER_PROPERTIES_ALLOWED_AUTH,
     MMC_F_BEARER_PROPERTIES_USER,
     MMC_F_BEARER_PROPERTIES_PASSWORD,
     MMC_F_BEARER_PROPERTIES_NUMBER,
@@ -243,6 +244,11 @@ typedef enum {
     MMC_F_BEARER_STATS_DURATION,
     MMC_F_BEARER_STATS_BYTES_RX,
     MMC_F_BEARER_STATS_BYTES_TX,
+    MMC_F_BEARER_STATS_ATTEMPTS,
+    MMC_F_BEARER_STATS_FAILED_ATTEMPTS,
+    MMC_F_BEARER_STATS_TOTAL_DURATION,
+    MMC_F_BEARER_STATS_TOTAL_BYTES_RX,
+    MMC_F_BEARER_STATS_TOTAL_BYTES_TX,
     MMC_F_CALL_GENERAL_DBUS_PATH,
     MMC_F_CALL_PROPERTIES_NUMBER,
     MMC_F_CALL_PROPERTIES_DIRECTION,
