@@ -538,17 +538,6 @@ mm_common_build_capability_combinations_none (void)
     return g_variant_builder_end (&builder);
 }
 
-GVariant *
-mm_common_build_capability_combinations_any (void)
-{
-    GVariantBuilder builder;
-
-    g_variant_builder_init (&builder, G_VARIANT_TYPE ("au"));
-    g_variant_builder_add_value (&builder,
-                                 g_variant_new_uint32 (MM_MODEM_CAPABILITY_ANY));
-    return g_variant_builder_end (&builder);
-}
-
 void
 mm_common_get_bands_from_string (const gchar *str,
                                  MMModemBand **bands,
@@ -1331,14 +1320,34 @@ mm_get_int_from_str (const gchar *str,
                      gint *out)
 {
     glong num;
+    guint eol = 0;
 
-    if (!str || !str[0])
+    if (!str)
+        return FALSE;
+
+    /* ignore all leading whitespaces */
+    while (str[0] == ' ')
+        str++;
+
+    if (!str[0])
         return FALSE;
 
     for (num = 0; str[num]; num++) {
-        if (str[num] != '+' && str[num] != '-' && !g_ascii_isdigit (str[num]))
+        if (str[num] != '+' && str[num] != '-' && !g_ascii_isdigit (str[num])) {
+            /* ignore \r\n at the end of the string */
+            if ((str[num] == '\r') || (str[num] == '\n')) {
+                eol++;
+                continue;
+            }
+            return FALSE;
+        }
+        /* if eol found before a valid char, the string is not parseable */
+        if (eol)
             return FALSE;
     }
+    /* if all characters were eol, the string is not parseable */
+    if (eol == num)
+        return FALSE;
 
     errno = 0;
     num = strtol (str, NULL, 10);
@@ -1354,17 +1363,10 @@ mm_get_int_from_match_info (GMatchInfo *match_info,
                             guint32 match_index,
                             gint *out)
 {
-    gchar *s;
-    gboolean ret;
+    g_autofree gchar *s = NULL;
 
-    s = g_match_info_fetch (match_info, match_index);
-    if (!s)
-        return FALSE;
-
-    ret = mm_get_int_from_str (s, out);
-    g_free (s);
-
-    return ret;
+    s = mm_get_string_unquoted_from_match_info (match_info, match_index);
+    return (s ? mm_get_int_from_str (s, out) : FALSE);
 }
 
 gboolean
@@ -1385,14 +1387,34 @@ mm_get_u64_from_str (const gchar *str,
                      guint64     *out)
 {
     guint64 num;
+    guint   eol = 0;
 
-    if (!str || !str[0])
+    if (!str)
+        return FALSE;
+
+    /* ignore all leading whitespaces */
+    while (str[0] == ' ')
+        str++;
+
+    if (!str[0])
         return FALSE;
 
     for (num = 0; str[num]; num++) {
-        if (!g_ascii_isdigit (str[num]))
+        if (!g_ascii_isdigit (str[num])) {
+            /* ignore \r\n at the end of the string */
+            if ((str[num] == '\r') || (str[num] == '\n')) {
+                eol++;
+                continue;
+            }
+            return FALSE;
+        }
+        /* if eol found before a valid char, the string is not parseable */
+        if (eol)
             return FALSE;
     }
+    /* if all characters were eol, the string is not parseable */
+    if (eol == num)
+        return FALSE;
 
     errno = 0;
     num = (guint64) strtoull (str, NULL, 10);
@@ -1421,10 +1443,15 @@ mm_get_u64_from_hex_str (const gchar *str,
                          guint64     *out)
 {
     guint64 num;
+    guint   eol = 0;
 
     if (!str)
         return FALSE;
 
+    /* ignore all leading whitespaces */
+    while (str[0] == ' ')
+        str++;
+
     if (g_str_has_prefix (str, "0x"))
         str = &str[2];
 
@@ -1432,9 +1459,21 @@ mm_get_u64_from_hex_str (const gchar *str,
         return FALSE;
 
     for (num = 0; str[num]; num++) {
-        if (!g_ascii_isxdigit (str[num]))
+        if (!g_ascii_isxdigit (str[num])) {
+            /* ignore \r\n at the end of the string */
+            if ((str[num] == '\r') || (str[num] == '\n')) {
+                eol++;
+                continue;
+            }
+            return FALSE;
+        }
+        /* if eol found before a valid char, the string is not parseable */
+        if (eol)
             return FALSE;
     }
+    /* if all characters were eol, the string is not parseable */
+    if (eol == num)
+        return FALSE;
 
     errno = 0;
     num = (guint64) strtoull (str, NULL, 16);
@@ -1464,25 +1503,44 @@ mm_get_u64_from_match_info (GMatchInfo *match_info,
                             guint32     match_index,
                             guint64    *out)
 {
-    gchar *s;
-    gboolean ret;
+    g_autofree gchar *s = NULL;
 
-    s = g_match_info_fetch (match_info, match_index);
-    if (!s)
+    s = mm_get_string_unquoted_from_match_info (match_info, match_index);
+    return (s ? mm_get_u64_from_str (s, out) : FALSE);
+}
+
+gboolean
+mm_get_uint_from_hex_match_info (GMatchInfo *match_info,
+                                 guint32     match_index,
+                                 guint      *out)
+{
+    guint64 num;
+
+    if (!mm_get_u64_from_hex_match_info (match_info, match_index, &num) || num > G_MAXUINT)
         return FALSE;
 
-    ret = mm_get_u64_from_str (s, out);
-    g_free (s);
+    *out = (guint)num;
+    return TRUE;
+}
 
-    return ret;
+gboolean
+mm_get_u64_from_hex_match_info (GMatchInfo *match_info,
+                                guint32     match_index,
+                                guint64    *out)
+{
+    g_autofree gchar *s = NULL;
+
+    s = mm_get_string_unquoted_from_match_info (match_info, match_index);
+    return (s ? mm_get_u64_from_hex_str (s, out) : FALSE);
 }
 
 gboolean
 mm_get_double_from_str (const gchar *str,
                         gdouble *out)
 {
-    gdouble num;
-    guint i;
+    gdouble  num;
+    guint    i;
+    guint    eol = 0;
 
     if (!str || !str[0])
         return FALSE;
@@ -1490,14 +1548,24 @@ mm_get_double_from_str (const gchar *str,
     for (i = 0; str[i]; i++) {
         /* we don't really expect numbers in scientific notation, so
          * don't bother looking for exponents and such */
-        if (str[i] != '-' &&
-            str[i] != '.' &&
-            !g_ascii_isdigit (str[i]))
+        if ((str[i] != '-') && (str[i] != '.') && !g_ascii_isdigit (str[i])) {
+            /* ignore \r\n at the end of the string */
+            if ((str[i] == '\r') || (str[i] == '\n')) {
+                eol++;
+                continue;
+            }
+            return FALSE;
+        }
+        /* if eol found before a valid char, the string is not parseable */
+        if (eol)
             return FALSE;
     }
+    /* if all characters were eol, the string is not parseable */
+    if (eol == i)
+        return FALSE;
 
     errno = 0;
-    num = strtod (str, NULL);
+    num = g_ascii_strtod (str, NULL);
     if (!errno) {
         *out = num;
         return TRUE;
@@ -1510,17 +1578,10 @@ mm_get_double_from_match_info (GMatchInfo *match_info,
                                guint32 match_index,
                                gdouble *out)
 {
-    gchar *s;
-    gboolean ret;
+    g_autofree gchar *s = NULL;
 
-    s = g_match_info_fetch (match_info, match_index);
-    if (!s)
-        return FALSE;
-
-    ret = mm_get_double_from_str (s, out);
-    g_free (s);
-
-    return ret;
+    s = mm_get_string_unquoted_from_match_info (match_info, match_index);
+    return (s ? mm_get_double_from_str (s, out) : FALSE);
 }
 
 gchar *
