@@ -40,6 +40,12 @@
 
 G_DEFINE_TYPE (MMModemFirmware, mm_modem_firmware, MM_GDBUS_TYPE_MODEM_FIRMWARE_PROXY)
 
+struct _MMModemFirmwarePrivate {
+    GMutex                    update_settings_mutex;
+    guint                     update_settings_id;
+    MMFirmwareUpdateSettings *update_settings;
+};
+
 /*****************************************************************************/
 
 /**
@@ -49,6 +55,8 @@ G_DEFINE_TYPE (MMModemFirmware, mm_modem_firmware, MM_GDBUS_TYPE_MODEM_FIRMWARE_
  * Gets the DBus path of the #MMObject which implements this interface.
  *
  * Returns: (transfer none): The DBus path of the #MMObject object.
+ *
+ * Since: 1.0
  */
 const gchar *
 mm_modem_firmware_get_path (MMModemFirmware *self)
@@ -63,9 +71,13 @@ mm_modem_firmware_get_path (MMModemFirmware *self)
  * mm_modem_firmware_dup_path:
  * @self: A #MMModemFirmware.
  *
- * Gets a copy of the DBus path of the #MMObject object which implements this interface.
+ * Gets a copy of the DBus path of the #MMObject object which implements this
+ * interface.
  *
- * Returns: (transfer full): The DBus path of the #MMObject. The returned value should be freed with g_free().
+ * Returns: (transfer full): The DBus path of the #MMObject. The returned value
+ * should be freed with g_free().
+ *
+ * Since: 1.0
  */
 gchar *
 mm_modem_firmware_dup_path (MMModemFirmware *self)
@@ -82,15 +94,134 @@ mm_modem_firmware_dup_path (MMModemFirmware *self)
 
 /*****************************************************************************/
 
+static void
+update_settings_updated (MMModemFirmware *self,
+                         GParamSpec      *pspec)
+{
+    g_mutex_lock (&self->priv->update_settings_mutex);
+    {
+        GVariant *variant;
+
+        g_clear_object (&self->priv->update_settings);
+        variant = mm_gdbus_modem_firmware_get_update_settings (MM_GDBUS_MODEM_FIRMWARE (self));
+        if (variant) {
+            GError *error = NULL;
+
+            self->priv->update_settings = mm_firmware_update_settings_new_from_variant (variant, &error);
+            if (error) {
+                g_warning ("Invalid update settings received: %s", error->message);
+                g_error_free (error);
+            }
+        }
+    }
+    g_mutex_unlock (&self->priv->update_settings_mutex);
+}
+
+static void
+ensure_internal_update_settings (MMModemFirmware           *self,
+                                 MMFirmwareUpdateSettings **dupl)
+{
+    g_mutex_lock (&self->priv->update_settings_mutex);
+    {
+        /* If this is the first time ever asking for the object, setup the
+         * update listener and the initial object, if any. */
+        if (!self->priv->update_settings_id) {
+            GVariant *variant;
+
+            variant = mm_gdbus_modem_firmware_dup_update_settings (MM_GDBUS_MODEM_FIRMWARE (self));
+            if (variant) {
+                GError *error = NULL;
+
+                self->priv->update_settings = mm_firmware_update_settings_new_from_variant (variant, &error);
+                if (error) {
+                    g_warning ("Invalid initial update settings: %s", error->message);
+                    g_error_free (error);
+                }
+                g_variant_unref (variant);
+            }
+
+            /* No need to clear this signal connection when freeing self */
+            self->priv->update_settings_id =
+                g_signal_connect (self,
+                                  "notify::update-settings",
+                                  G_CALLBACK (update_settings_updated),
+                                  NULL);
+        }
+
+        if (dupl && self->priv->update_settings)
+            *dupl = g_object_ref (self->priv->update_settings);
+    }
+    g_mutex_unlock (&self->priv->update_settings_mutex);
+}
+
+/**
+ * mm_modem_firmware_get_update_settings:
+ * @self: A #MMModemFirmware.
+ *
+ * Gets a #MMFirmwareUpdateSettings object specifying the expected update
+ * settings.
+ *
+ * <warning>The values reported by @self are not updated when the values in the
+ * interface change. Instead, the client is expected to call
+ * mm_modem_firmware_get_update_settings() again to get a new
+ * #MMFirmwareUpdateSettings with the new values.</warning>
+ *
+ * Returns: (transfer full): A #MMFirmwareUpdateSettings that must be freed with
+ * g_object_unref() or %NULL if unknown.
+ *
+ * Since: 1.10
+ */
+MMFirmwareUpdateSettings *
+mm_modem_firmware_get_update_settings (MMModemFirmware *self)
+{
+    MMFirmwareUpdateSettings *update_settings = NULL;
+
+    g_return_val_if_fail (MM_IS_MODEM_FIRMWARE (self), NULL);
+
+    ensure_internal_update_settings (self, &update_settings);
+    return update_settings;
+}
+
+/**
+ * mm_modem_firmware_peek_update_settings:
+ * @self: A #MMModemFirmware.
+ *
+ * Gets a #MMFirmwareUpdateSettings object specifying the expected update
+ * settings.
+ *
+ * <warning>The returned value is only valid until the property changes so
+ * it is only safe to use this function on the thread where
+ * @self was constructed. Use mm_modem_firmware_get_update_settings() if on
+ * another thread.</warning>
+ *
+ * Returns: (transfer none): A #MMFirmwareUpdateSettings. Do not free the
+ * returned value, it belongs to @self.
+ *
+ * Since: 1.10
+ */
+MMFirmwareUpdateSettings *
+mm_modem_firmware_peek_update_settings (MMModemFirmware *self)
+{
+    g_return_val_if_fail (MM_IS_MODEM_FIRMWARE (self), NULL);
+
+    ensure_internal_update_settings (self, NULL);
+    return self->priv->update_settings;
+}
+
+/*****************************************************************************/
+
 /**
  * mm_modem_firmware_select_finish:
  * @self: A #MMModemFirmware.
- * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to mm_modem_firmware_select().
+ * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to
+ *  mm_modem_firmware_select().
  * @error: Return location for error or %NULL.
  *
  * Finishes an operation started with mm_modem_firmware_select().
  *
  * Returns: %TRUE if the selection was successful, %FALSE if @error is set.
+ *
+ * Since: 1.0
  */
 gboolean
 mm_modem_firmware_select_finish (MMModemFirmware *self,
@@ -107,7 +238,8 @@ mm_modem_firmware_select_finish (MMModemFirmware *self,
  * @self: A #MMModemFirmware.
  * @unique_id: Unique ID of the firmware image to select.
  * @cancellable: (allow-none): A #GCancellable or %NULL.
- * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
+ * @callback: A #GAsyncReadyCallback to call when the request is satisfied or
+ *  %NULL.
  * @user_data: User data to pass to @callback.
  *
  * Asynchronously selects a firmware image to boot.
@@ -115,10 +247,15 @@ mm_modem_firmware_select_finish (MMModemFirmware *self,
  * <warning>The modem will possibly disappear once this action is run, as it
  * needs to reboot in order to select the new image.</warning>
  *
- * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
- * You can then call mm_modem_firmware_select_finish() to get the result of the operation.
+ * When the operation is finished, @callback will be invoked in the
+ * <link linkend="g-main-context-push-thread-default">thread-default main loop</link>
+ * of the thread you are calling this method from. You can then call
+ * mm_modem_firmware_select_finish() to get the result of the operation.
  *
- * See mm_modem_firmware_select_sync() for the synchronous, blocking version of this method.
+ * See mm_modem_firmware_select_sync() for the synchronous, blocking version of
+ * this method.
+ *
+ * Since: 1.0
  */
 void
 mm_modem_firmware_select (MMModemFirmware *self,
@@ -128,7 +265,7 @@ mm_modem_firmware_select (MMModemFirmware *self,
                           gpointer user_data)
 {
     g_return_if_fail (MM_IS_MODEM_FIRMWARE (self));
-    g_return_if_fail (unique_id != NULL || unique_id[0] == '\0');
+    g_return_if_fail (unique_id != NULL && unique_id[0] != '\0');
 
     mm_gdbus_modem_firmware_call_select (MM_GDBUS_MODEM_FIRMWARE (self), unique_id, cancellable, callback, user_data);
 }
@@ -145,10 +282,12 @@ mm_modem_firmware_select (MMModemFirmware *self,
  * <warning>The modem will possibly disappear once this action is run, as it
  * needs to reboot in order to select the new image.</warning>
  *
- * The calling thread is blocked until a reply is received. See mm_modem_firmware_select()
- * for the asynchronous version of this method.
+ * The calling thread is blocked until a reply is received. See
+ * mm_modem_firmware_select() for the asynchronous version of this method.
  *
  * Returns: %TRUE if the selection was successful, %FALSE if @error is set.
+ *
+ * Since: 1.0
  */
 gboolean
 mm_modem_firmware_select_sync (MMModemFirmware *self,
@@ -157,7 +296,7 @@ mm_modem_firmware_select_sync (MMModemFirmware *self,
                                GError **error)
 {
     g_return_val_if_fail (MM_IS_MODEM_FIRMWARE (self), FALSE);
-    g_return_val_if_fail (unique_id != NULL || unique_id[0] == '\0', FALSE);
+    g_return_val_if_fail (unique_id != NULL && unique_id[0] != '\0', FALSE);
 
     return mm_gdbus_modem_firmware_call_select_sync (MM_GDBUS_MODEM_FIRMWARE (self), unique_id, cancellable, error);
 }
@@ -244,14 +383,22 @@ build_results (const gchar *str_selected,
 /**
  * mm_modem_firmware_list_finish:
  * @self: A #MMModemFirmware.
- * @selected: (out) (allow-none) (transfer full): The selected firmware slot, or NULL if no slot is selected (such as if all slots are empty, or no slots exist). The returned value should be freed with g_object_unref().
- * @installed: (out) (allow-none) (transfer full) (element-type ModemManager.FirmwareProperties): A list of #MMFirmwareProperties objects specifying the installed images. The returned value should be freed with g_list_free_full() using g_object_unref() as #GDestroyNotify.
- * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to mm_modem_firmware_list().
+ * @selected: (out) (allow-none) (transfer full): The selected firmware slot, or
+ *  %NULL if no slot is selected (such as if all slots are empty, or no slots
+ *  exist). The returned value should be freed with g_object_unref().
+ * @installed: (out) (allow-none) (transfer full) (element-type ModemManager.FirmwareProperties):
+ *  A list of #MMFirmwareProperties objects specifying the installed images. The
+ *  returned value should be freed with g_list_free_full() using
+ *  g_object_unref() as #GDestroyNotify.
+ * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to
+ *  mm_modem_firmware_list().
  * @error: Return location for error or %NULL.
  *
  * Finishes an operation started with mm_modem_firmware_list().
  *
  * Returns: %TRUE if the list was correctly retrieved, %FALSE if @error is set.
+ *
+ * Since: 1.0
  */
 gboolean
 mm_modem_firmware_list_finish (MMModemFirmware *self,
@@ -293,15 +440,21 @@ mm_modem_firmware_list_finish (MMModemFirmware *self,
  * mm_modem_firmware_list:
  * @self: A #MMModemFirmware.
  * @cancellable: (allow-none): A #GCancellable or %NULL.
- * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
+ * @callback: A #GAsyncReadyCallback to call when the request is satisfied or
+ *  %NULL.
  * @user_data: User data to pass to @callback.
  *
  * Asynchronously gets the list of available firmware images.
  *
- * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
- * You can then call mm_modem_firmware_list_finish() to get the result of the operation.
+ * When the operation is finished, @callback will be invoked in the
+ * <link linkend="g-main-context-push-thread-default">thread-default main loop</link>
+ * of the thread you are calling this method from. You can then call
+ * mm_modem_firmware_list_finish() to get the result of the operation.
  *
- * See mm_modem_firmware_list_sync() for the synchronous, blocking version of this method.
+ * See mm_modem_firmware_list_sync() for the synchronous, blocking version of
+ * this method.
+ *
+ * Since: 1.0
  */
 void
 mm_modem_firmware_list (MMModemFirmware *self,
@@ -320,17 +473,24 @@ mm_modem_firmware_list (MMModemFirmware *self,
 /**
  * mm_modem_firmware_list_sync:
  * @self: A #MMModemFirmware.
- * @selected: (out) (allow-none) (transfer full): The selected firmware slot, or NULL if no slot is selected (such as if all slots are empty, or no slots exist). The returned value should be freed with g_object_unref().
- * @installed: (out) (allow-none) (transfer full) (element-type ModemManager.FirmwareProperties): A list of #MMFirmwareProperties objects specifying the installed images. The returned value should be freed with g_list_free_full() using g_object_unref() as #GDestroyNotify.
+ * @selected: (out) (allow-none) (transfer full): The selected firmware slot,
+ *  or NULL if no slot is selected (such as if all slots are empty, or no slots
+ *  exist). The returned value should be freed with g_object_unref().
+ * @installed: (out) (allow-none) (transfer full) (element-type ModemManager.FirmwareProperties):
+ *  A list of #MMFirmwareProperties objects specifying the installed images. The
+ *  returned value should be freed with g_list_free_full() using
+ *  g_object_unref() as #GDestroyNotify.
  * @cancellable: (allow-none): A #GCancellable or %NULL.
  * @error: Return firmware for error or %NULL.
  *
  * Synchronously gets the list of available firmware images.
  *
- * The calling thread is blocked until a reply is received. See mm_modem_firmware_list()
- * for the asynchronous version of this method.
+ * The calling thread is blocked until a reply is received. See
+ * mm_modem_firmware_list() for the asynchronous version of this method.
  *
  * Returns: %TRUE if the list was correctly retrieved, %FALSE if @error is set.
+ *
+ * Since: 1.0
  */
 gboolean
 mm_modem_firmware_list_sync (MMModemFirmware *self,
@@ -372,9 +532,38 @@ mm_modem_firmware_list_sync (MMModemFirmware *self,
 static void
 mm_modem_firmware_init (MMModemFirmware *self)
 {
+    self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, MM_TYPE_MODEM_FIRMWARE, MMModemFirmwarePrivate);
+    g_mutex_init (&self->priv->update_settings_mutex);
+}
+
+static void
+finalize (GObject *object)
+{
+    MMModemFirmware *self = MM_MODEM_FIRMWARE (object);
+
+    g_mutex_clear (&self->priv->update_settings_mutex);
+
+    G_OBJECT_CLASS (mm_modem_firmware_parent_class)->finalize (object);
+}
+
+static void
+dispose (GObject *object)
+{
+    MMModemFirmware *self = MM_MODEM_FIRMWARE (object);
+
+    g_clear_object (&self->priv->update_settings);
+
+    G_OBJECT_CLASS (mm_modem_firmware_parent_class)->dispose (object);
 }
 
 static void
 mm_modem_firmware_class_init (MMModemFirmwareClass *modem_class)
 {
+    GObjectClass *object_class = G_OBJECT_CLASS (modem_class);
+
+    g_type_class_add_private (object_class, sizeof (MMModemFirmwarePrivate));
+
+    /* Virtual methods */
+    object_class->dispose = dispose;
+    object_class->finalize = finalize;
 }
