@@ -33,7 +33,7 @@
  * mm_modem_simple_get_status_sync().
  */
 
-G_DEFINE_TYPE (MMSimpleStatus, mm_simple_status, G_TYPE_OBJECT);
+G_DEFINE_TYPE (MMSimpleStatus, mm_simple_status, G_TYPE_OBJECT)
 
 enum {
     PROP_0,
@@ -73,8 +73,6 @@ struct _MMSimpleStatusPrivate {
     gchar *modem_3gpp_operator_code;
     /* 3GPP operator name, given only when registered, signature 's' */
     gchar *modem_3gpp_operator_name;
-    /* 3GPP subsctiption state, signature 'u' */
-    MMModem3gppSubscriptionState modem_3gpp_subscription_state;
 
     /* <--- From the Modem CDMA interface ---> */
     /* CDMA/CDMA1x registration state, signature 'u' */
@@ -96,6 +94,8 @@ struct _MMSimpleStatusPrivate {
  * Gets the state of the modem.
  *
  * Returns: a #MMModemState.
+ *
+ * Since: 1.0
  */
 MMModemState
 mm_simple_status_get_state (MMSimpleStatus *self)
@@ -110,11 +110,14 @@ mm_simple_status_get_state (MMSimpleStatus *self)
 /**
  * mm_simple_status_get_signal_quality:
  * @self: a #MMSimpleStatus.
- * @recent: (out) (allow-none): indication of whether the given signal quality is considered recent.
+ * @recent: (out) (allow-none): indication of whether the given signal quality
+ *  is considered recent.
  *
  * Gets the signal quality.
  *
  * Returns: the signal quality.
+ *
+ * Since: 1.0
  */
 guint32
 mm_simple_status_get_signal_quality (MMSimpleStatus *self,
@@ -142,10 +145,13 @@ mm_simple_status_get_signal_quality (MMSimpleStatus *self,
 /**
  * mm_simple_status_get_current_bands:
  * @self: a #MMSimpleStatus.
- * @bands: (out): location for an array of #MMModemBand values. Do not free the returned value, it is owned by @self.
+ * @bands: (out): location for an array of #MMModemBand values. Do not free the
+ *  returned value, it is owned by @self.
  * @n_bands: (out): number of elements in @bands.
  *
  * Gets the currently used frequency bands.
+ *
+ * Since: 1.0
  */
 void
 mm_simple_status_get_current_bands (MMSimpleStatus *self,
@@ -170,6 +176,8 @@ mm_simple_status_get_current_bands (MMSimpleStatus *self,
  * Gets the currently used access technologies.
  *
  * Returns: a bitmask of #MMModemAccessTechnology values.
+ *
+ * Since: 1.0
  */
 MMModemAccessTechnology
 mm_simple_status_get_access_technologies (MMSimpleStatus *self)
@@ -188,6 +196,8 @@ mm_simple_status_get_access_technologies (MMSimpleStatus *self)
  * Gets the current state of the registration in the 3GPP network.
  *
  * Returns: a #MMModem3gppRegistrationState.
+ *
+ * Since: 1.0
  */
 MMModem3gppRegistrationState
 mm_simple_status_get_3gpp_registration_state (MMSimpleStatus *self)
@@ -203,9 +213,13 @@ mm_simple_status_get_3gpp_registration_state (MMSimpleStatus *self)
  * mm_simple_status_get_3gpp_operator_code:
  * @self: a #MMSimpleStatus.
  *
- * Gets the MCC/MNC of the operator of the 3GPP network where the modem is registered.
+ * Gets the MCC/MNC of the operator of the 3GPP network where the modem is
+ * registered.
  *
- * Returns: the operator code, or %NULL if unknown. Do not free the returned value, it is owned by @self.
+ * Returns: the operator code, or %NULL if unknown. Do not free the returned
+ * value, it is owned by @self.
+ *
+ * Since: 1.0
  */
 const gchar *
 mm_simple_status_get_3gpp_operator_code (MMSimpleStatus *self)
@@ -221,9 +235,13 @@ mm_simple_status_get_3gpp_operator_code (MMSimpleStatus *self)
  * mm_simple_status_get_3gpp_operator_name:
  * @self: a #MMSimpleStatus.
  *
- * Gets the name of the operator of the 3GPP network where the modem is registered.
+ * Gets the name of the operator of the 3GPP network where the modem is
+ * registered.
  *
- * Returns: the operator name, or %NULL if unknown. Do not free the returned value, it is owned by @self.
+ * Returns: the operator name, or %NULL if unknown. Do not free the returned
+ * value, it is owned by @self.
+ *
+ * Since: 1.0
  */
 const gchar *
 mm_simple_status_get_3gpp_operator_name (MMSimpleStatus *self)
@@ -235,6 +253,8 @@ mm_simple_status_get_3gpp_operator_name (MMSimpleStatus *self)
 
 /*****************************************************************************/
 
+#ifndef MM_DISABLE_DEPRECATED
+
 /**
  * mm_simple_status_get_3gpp_subscription_state:
  * @self: a #MMSimpleStatus.
@@ -242,15 +262,19 @@ mm_simple_status_get_3gpp_operator_name (MMSimpleStatus *self)
  * Gets the current subscription status of the account.
  *
  * Returns: a #MMModem3gppSubscriptionState.
+ *
+ * Since: 1.0
+ * Deprecated: 1.12.0. The value of this property can only be obtained with
+ * operator specific logic (e.g. processing specific PCO info), and therefore
+ * it doesn't make sense to expose it in the ModemManager interface.
  */
 MMModem3gppSubscriptionState
 mm_simple_status_get_3gpp_subscription_state (MMSimpleStatus *self)
 {
-    g_return_val_if_fail (MM_IS_SIMPLE_STATUS (self), MM_MODEM_3GPP_SUBSCRIPTION_STATE_UNKNOWN);
-
-    return self->priv->modem_3gpp_subscription_state;
+    return MM_MODEM_3GPP_SUBSCRIPTION_STATE_UNKNOWN;
 }
 
+#endif /* MM_DISABLE_DEPRECATED */
 
 /*****************************************************************************/
 
@@ -261,6 +285,8 @@ mm_simple_status_get_3gpp_subscription_state (MMSimpleStatus *self)
  * Gets the current state of the registration in the CDMA-1x network.
  *
  * Returns: a #MMModemCdmaRegistrationState.
+ *
+ * Since: 1.0
  */
 MMModemCdmaRegistrationState
 mm_simple_status_get_cdma_cdma1x_registration_state (MMSimpleStatus *self)
@@ -279,6 +305,8 @@ mm_simple_status_get_cdma_cdma1x_registration_state (MMSimpleStatus *self)
  * Gets the current state of the registration in the EV-DO network.
  *
  * Returns: a #MMModemCdmaRegistrationState.
+ *
+ * Since: 1.0
  */
 MMModemCdmaRegistrationState
 mm_simple_status_get_cdma_evdo_registration_state (MMSimpleStatus *self)
@@ -297,6 +325,8 @@ mm_simple_status_get_cdma_evdo_registration_state (MMSimpleStatus *self)
  * Gets the System Identification number of the CDMA network.
  *
  * Returns: the SID, or %MM_MODEM_CDMA_SID_UNKNOWN if unknown.
+ *
+ * Since: 1.0
  */
 guint
 mm_simple_status_get_cdma_sid (MMSimpleStatus *self)
@@ -315,6 +345,8 @@ mm_simple_status_get_cdma_sid (MMSimpleStatus *self)
  * Gets the Network Identification number of the CDMA network.
  *
  * Returns: the NID, or %MM_MODEM_CDMA_NID_UNKNOWN if unknown.
+ *
+ * Since: 1.0
  */
 guint
 mm_simple_status_get_cdma_nid (MMSimpleStatus *self)
@@ -326,6 +358,9 @@ mm_simple_status_get_cdma_nid (MMSimpleStatus *self)
 
 /*****************************************************************************/
 
+/**
+ * mm_simple_status_get_dictionary: (skip)
+ */
 GVariant *
 mm_simple_status_get_dictionary (MMSimpleStatus *self)
 {
@@ -397,17 +432,14 @@ mm_simple_status_get_dictionary (MMSimpleStatus *self)
 
     }
 
-    if (self->priv->modem_3gpp_subscription_state)
-        g_variant_builder_add (&builder,
-                               "{sv}",
-                               MM_SIMPLE_PROPERTY_3GPP_SUBSCRIPTION_STATE,
-                               g_variant_new_uint32 (self->priv->modem_3gpp_subscription_state));
-
     return g_variant_ref_sink (g_variant_builder_end (&builder));
 }
 
 /*****************************************************************************/
 
+/**
+ * mm_simple_status_new_from_dictionary: (skip)
+ */
 MMSimpleStatus *
 mm_simple_status_new_from_dictionary (GVariant *dictionary,
                                       GError **error)
@@ -442,7 +474,6 @@ mm_simple_status_new_from_dictionary (GVariant *dictionary,
         if (g_str_equal (key, MM_SIMPLE_PROPERTY_STATE) ||
             g_str_equal (key, MM_SIMPLE_PROPERTY_ACCESS_TECHNOLOGIES) ||
             g_str_equal (key, MM_SIMPLE_PROPERTY_3GPP_REGISTRATION_STATE) ||
-            g_str_equal (key, MM_SIMPLE_PROPERTY_3GPP_SUBSCRIPTION_STATE) ||
             g_str_equal (key, MM_SIMPLE_PROPERTY_CDMA_CDMA1X_REGISTRATION_STATE) ||
             g_str_equal (key, MM_SIMPLE_PROPERTY_CDMA_EVDO_REGISTRATION_STATE) ||
             g_str_equal (key, MM_SIMPLE_PROPERTY_CDMA_SID) ||
@@ -487,6 +518,9 @@ mm_simple_status_new_from_dictionary (GVariant *dictionary,
 
 /*****************************************************************************/
 
+/**
+ * mm_simple_status_new: (skip)
+ */
 MMSimpleStatus *
 mm_simple_status_new (void)
 {
@@ -535,7 +569,7 @@ set_property (GObject *object,
         self->priv->modem_3gpp_operator_name = g_value_dup_string (value);
         break;
     case PROP_3GPP_SUBSCRIPTION_STATE:
-        self->priv->modem_3gpp_subscription_state = g_value_get_enum (value);
+        /* no-op */
         break;
     case PROP_CDMA_CDMA1X_REGISTRATION_STATE:
         self->priv->modem_cdma_cdma1x_registration_state = g_value_get_enum (value);
@@ -586,7 +620,7 @@ get_property (GObject *object,
         g_value_set_string (value, self->priv->modem_3gpp_operator_name);
         break;
     case PROP_3GPP_SUBSCRIPTION_STATE:
-        g_value_set_enum (value, self->priv->modem_3gpp_subscription_state);
+        g_value_set_enum (value, MM_MODEM_3GPP_SUBSCRIPTION_STATE_UNKNOWN);
         break;
     case PROP_CDMA_CDMA1X_REGISTRATION_STATE:
         g_value_set_enum (value, self->priv->modem_cdma_cdma1x_registration_state);
@@ -617,7 +651,6 @@ mm_simple_status_init (MMSimpleStatus *self)
     self->priv->state = MM_MODEM_STATE_UNKNOWN;
     self->priv->access_technologies = MM_MODEM_ACCESS_TECHNOLOGY_UNKNOWN;
     self->priv->modem_3gpp_registration_state = MM_MODEM_3GPP_REGISTRATION_STATE_UNKNOWN;
-    self->priv->modem_3gpp_subscription_state = MM_MODEM_3GPP_SUBSCRIPTION_STATE_UNKNOWN;
     self->priv->current_bands = g_variant_ref_sink (mm_common_build_bands_unknown ());
     self->priv->signal_quality = g_variant_ref_sink (g_variant_new ("(ub)", 0, 0));
     self->priv->modem_cdma_cdma1x_registration_state = MM_MODEM_CDMA_REGISTRATION_STATE_UNKNOWN;
@@ -717,7 +750,7 @@ mm_simple_status_class_init (MMSimpleStatusClass *klass)
     properties[PROP_3GPP_SUBSCRIPTION_STATE] =
         g_param_spec_enum (MM_SIMPLE_PROPERTY_3GPP_SUBSCRIPTION_STATE,
                            "3GPP subscription state",
-                           "Subscription state of the account",
+                           "Subscription state of the account (deprecated)",
                            MM_TYPE_MODEM_3GPP_SUBSCRIPTION_STATE,
                            MM_MODEM_3GPP_SUBSCRIPTION_STATE_UNKNOWN,
                            G_PARAM_READWRITE);
