@@ -135,6 +135,8 @@ nv_mode_pref_from_qcdm (uint8_t qcdm)
         return DIAG_NV_MODE_PREF_GSM_UMTS_LTE_ONLY;
     case QCDM_CMD_NV_MODE_PREF_ITEM_MODE_PREF_1X_HDR_LTE_ONLY:
         return DIAG_NV_MODE_PREF_1X_HDR_LTE_ONLY;
+    default:
+        break;
     }
     return DIAG_NV_MODE_PREF_AUTO;
 };
@@ -753,7 +755,7 @@ qcdm_cmd_pilot_sets_result_get_pilot (QcdmResult *result,
     *out_pn_offset = set->pn_offset;
     *out_ecio = set->ecio;
     /* EC/IO is in units of -0.5 dB per the specs */
-    *out_db = (float) set->ecio * -0.5;
+    *out_db = (float) (set->ecio * -0.5);
     return TRUE;
 }
 
