@@ -22,7 +22,7 @@
 #define _LIBMM_INSIDE_MM
 #include <libmm-glib.h>
 
-#include "mm-log.h"
+#include "mm-log-object.h"
 #include "mm-modem-helpers.h"
 #include "mm-modem-helpers-huawei.h"
 
@@ -163,6 +163,7 @@ match_info_to_ip4_addr (GMatchInfo *match_info,
     gchar buf[9];
     gsize len, bin_len;
     gboolean success = FALSE;
+    guint32 aux;
 
     s = g_match_info_fetch (match_info, match_index);
     g_return_val_if_fail (s != NULL, FALSE);
@@ -190,7 +191,8 @@ match_info_to_ip4_addr (GMatchInfo *match_info,
     if (!bin || bin_len != 4)
         goto done;
 
-    *out_addr = GUINT32_SWAP_LE_BE (*((guint32 *) bin));
+    memcpy (&aux, bin, 4);
+    *out_addr = GUINT32_SWAP_LE_BE (aux);
     success = TRUE;
 
 done:
@@ -429,8 +431,9 @@ mode_from_prefmode (guint huawei_mode,
 }
 
 GArray *
-mm_huawei_parse_prefmode_test (const gchar *response,
-                               GError **error)
+mm_huawei_parse_prefmode_test (const gchar  *response,
+                               gpointer      log_object,
+                               GError      **error)
 {
     gchar **split;
     guint i;
@@ -461,12 +464,12 @@ mm_huawei_parse_prefmode_test (const gchar *response,
             continue;
 
         if (!mm_get_uint_from_str (split[i], &val)) {
-            mm_dbg ("Error parsing ^PREFMODE value: %s", split[i]);
+            mm_obj_dbg (log_object, "error parsing ^PREFMODE value '%s'", split[i]);
             continue;
         }
 
         if (!mode_from_prefmode (val, &preferred, &inner_error)) {
-            mm_dbg ("Unhandled ^PREFMODE: %s", inner_error->message);
+            mm_obj_dbg (log_object, "unhandled ^PREFMODE value: %s", inner_error->message);
             g_error_free (inner_error);
             continue;
         }
@@ -521,7 +524,7 @@ mm_huawei_parse_prefmode_response (const gchar *response,
                                    const GArray *supported_mode_combinations,
                                    GError **error)
 {
-    gint mode;
+    guint mode;
     guint i;
 
     /* Format:
@@ -530,7 +533,7 @@ mm_huawei_parse_prefmode_response (const gchar *response,
      */
 
     response = mm_strip_tag (response, "^PREFMODE:");
-    if (!sscanf (response, "%d", &mode)) {
+    if (!mm_get_uint_from_str (response, &mode)) {
         /* Dump error to upper layer */
         g_set_error (error,
                      MM_CORE_ERROR,
@@ -708,9 +711,10 @@ mode_from_syscfg (guint huawei_mode,
 }
 
 static GArray *
-parse_syscfg_modes (const gchar *modes_str,
-                    const gchar *acqorder_str,
-                    GError **error)
+parse_syscfg_modes (const gchar  *modes_str,
+                    const gchar  *acqorder_str,
+                    gpointer      log_object,
+                    GError      **error)
 {
     GArray *out;
     gchar **split;
@@ -720,7 +724,7 @@ parse_syscfg_modes (const gchar *modes_str,
 
     /* Start parsing acquisition order */
     if (!sscanf (acqorder_str, "%d-%d", &min_acqorder, &max_acqorder))
-        mm_dbg ("Error parsing ^SYSCFG acquisition order range (%s)", acqorder_str);
+        mm_obj_dbg (log_object, "error parsing ^SYSCFG acquisition order range '%s'", acqorder_str);
 
     /* Just in case, we default to supporting only auto */
     if (max_acqorder < min_acqorder) {
@@ -741,13 +745,13 @@ parse_syscfg_modes (const gchar *modes_str,
         MMHuaweiSyscfgCombination combination;
 
         if (!mm_get_uint_from_str (mm_strip_quotes (split[i]), &val)) {
-            mm_dbg ("Error parsing ^SYSCFG mode value: %s", split[i]);
+            mm_obj_dbg (log_object, "error parsing ^SYSCFG mode value: %s", split[i]);
             continue;
         }
 
         if (!mode_from_syscfg (val, &allowed, &inner_error)) {
             if (inner_error) {
-                mm_dbg ("Unhandled ^SYSCFG: %s", inner_error->message);
+                mm_obj_dbg (log_object, "unhandled ^SYSCFG: %s", inner_error->message);
                 g_error_free (inner_error);
             }
             continue;
@@ -808,8 +812,9 @@ parse_syscfg_modes (const gchar *modes_str,
 }
 
 GArray *
-mm_huawei_parse_syscfg_test (const gchar *response,
-                             GError **error)
+mm_huawei_parse_syscfg_test (const gchar  *response,
+                             gpointer      log_object,
+                             GError      **error)
 {
     gchar **split;
     GError *inner_error = NULL;
@@ -846,7 +851,7 @@ mm_huawei_parse_syscfg_test (const gchar *response,
     }
 
     /* Parse supported mode combinations */
-    out = parse_syscfg_modes (split[0], split[1], &inner_error);
+    out = parse_syscfg_modes (split[0], split[1], log_object, &inner_error);
 
     g_strfreev (split);
 
@@ -989,7 +994,7 @@ parse_mode_combination_string (const gchar *mode_str,
     case 1:
         /* If only one mode allowed, NONE preferred */
         *preferred = MM_MODEM_MODE_NONE;
-        /* fall down */
+        /* fall through */
     default:
         return TRUE;
     }
@@ -1350,7 +1355,7 @@ mm_huawei_parse_hcsq_response (const gchar *response,
     gboolean ret = FALSE;
     char *s;
 
-    r = g_regex_new ("\\^HCSQ:\\s*\"([a-zA-Z]*)\",(\\d+),?(\\d+)?,?(\\d+)?,?(\\d+)?,?(\\d+)?$", 0, 0, NULL);
+    r = g_regex_new ("\\^HCSQ:\\s*\"?([a-zA-Z]*)\"?,(\\d+),?(\\d+)?,?(\\d+)?,?(\\d+)?,?(\\d+)?$", 0, 0, NULL);
     g_assert (r != NULL);
 
     if (!g_regex_match_full (r, response, -1, 0, 0, &match_info, &match_error)) {
