@@ -22,7 +22,8 @@
 #define _LIBMM_INSIDE_MM
 #include <libmm-glib.h>
 
-#include "mm-log.h"
+#include "mm-log-test.h"
+#include "mm-log-object.h"
 #include "mm-modem-helpers.h"
 #include "mm-modem-helpers-huawei.h"
 
@@ -386,27 +387,21 @@ test_prefmode (void)
                 n_expected_combinations++;
         }
 
-        combinations = mm_huawei_parse_prefmode_test (prefmode_tests[i].str, &error);
+        combinations = mm_huawei_parse_prefmode_test (prefmode_tests[i].str, NULL, &error);
         g_assert_no_error (error);
         g_assert (combinations != NULL);
         g_assert_cmpuint (combinations->len, ==, n_expected_combinations);
 
         for (j = 0; j < combinations->len; j++) {
             MMHuaweiPrefmodeCombination *single;
-            gchar *allowed_str;
-            gchar *preferred_str;
+            g_autofree gchar *allowed_str = NULL;
+            g_autofree gchar *preferred_str = NULL;
 
             single = &g_array_index (combinations, MMHuaweiPrefmodeCombination, j);
             allowed_str = mm_modem_mode_build_string_from_mask (single->allowed);
             preferred_str = mm_modem_mode_build_string_from_mask (single->preferred);
-            mm_dbg ("Test[%u], Combination[%u]: %u, \"%s\", \"%s\"",
-                    i,
-                    j,
-                    single->prefmode,
-                    allowed_str,
-                    preferred_str);
-            g_free (allowed_str);
-            g_free (preferred_str);
+            mm_obj_dbg (NULL, "test[%u], combination[%u]: %u, \"%s\", \"%s\"",
+                        i, j, single->prefmode, allowed_str, preferred_str);
         }
 
         for (j = 0; j < combinations->len; j++) {
@@ -472,7 +467,7 @@ test_prefmode_response (void)
         const MMHuaweiPrefmodeCombination *found;
         GError *error = NULL;
 
-        combinations = mm_huawei_parse_prefmode_test (prefmode_response_tests[i].format, NULL);
+        combinations = mm_huawei_parse_prefmode_test (prefmode_response_tests[i].format, NULL, NULL);
         g_assert (combinations != NULL);
 
         found = mm_huawei_parse_prefmode_response (prefmode_response_tests[i].str,
@@ -622,28 +617,21 @@ test_syscfg (void)
                 n_expected_combinations++;
         }
 
-        combinations = mm_huawei_parse_syscfg_test (syscfg_tests[i].str, &error);
+        combinations = mm_huawei_parse_syscfg_test (syscfg_tests[i].str, NULL, &error);
         g_assert_no_error (error);
         g_assert (combinations != NULL);
         g_assert_cmpuint (combinations->len, ==, n_expected_combinations);
 
         for (j = 0; j < combinations->len; j++) {
             MMHuaweiSyscfgCombination *single;
-            gchar *allowed_str;
-            gchar *preferred_str;
+            g_autofree gchar *allowed_str = NULL;
+            g_autofree gchar *preferred_str = NULL;
 
             single = &g_array_index (combinations, MMHuaweiSyscfgCombination, j);
             allowed_str = mm_modem_mode_build_string_from_mask (single->allowed);
             preferred_str = mm_modem_mode_build_string_from_mask (single->preferred);
-            mm_dbg ("Test[%u], Combination[%u]: %u, %u, \"%s\", \"%s\"",
-                    i,
-                    j,
-                    single->mode,
-                    single->acqorder,
-                    allowed_str,
-                    preferred_str);
-            g_free (allowed_str);
-            g_free (preferred_str);
+            mm_obj_dbg (NULL, "test[%u], combination[%u]: %u, %u, \"%s\", \"%s\"",
+                        i, j, single->mode, single->acqorder, allowed_str, preferred_str);
         }
 
         for (j = 0; j < combinations->len; j++) {
@@ -736,7 +724,7 @@ test_syscfg_response (void)
         const MMHuaweiSyscfgCombination *found;
         GError *error = NULL;
 
-        combinations = mm_huawei_parse_syscfg_test (syscfg_response_tests[i].format, NULL);
+        combinations = mm_huawei_parse_syscfg_test (syscfg_response_tests[i].format, NULL, NULL);
         g_assert (combinations != NULL);
 
         found = mm_huawei_parse_syscfg_response (syscfg_response_tests[i].str,
@@ -772,22 +760,22 @@ static const SyscfgexTest syscfgex_tests[] = {
         "\r\n",
         {
             {
-                .mode_str = "00",
+                .mode_str = (gchar *) "00",
                 .allowed = (MM_MODEM_MODE_4G | MM_MODEM_MODE_3G | MM_MODEM_MODE_2G),
                 .preferred = MM_MODEM_MODE_NONE
             },
             {
-                .mode_str = "03",
+                .mode_str = (gchar *) "03",
                 .allowed = MM_MODEM_MODE_4G,
                 .preferred = MM_MODEM_MODE_NONE
             },
             {
-                .mode_str = "02",
+                .mode_str = (gchar *) "02",
                 .allowed = MM_MODEM_MODE_3G,
                 .preferred = MM_MODEM_MODE_NONE
             },
             {
-                .mode_str = "01",
+                .mode_str = (gchar *) "01",
                 .allowed = MM_MODEM_MODE_2G,
                 .preferred = MM_MODEM_MODE_NONE
             },
@@ -803,17 +791,17 @@ static const SyscfgexTest syscfgex_tests[] = {
         "\r\n",
         {
             {
-                .mode_str = "030201",
+                .mode_str = (gchar *) "030201",
                 .allowed = (MM_MODEM_MODE_4G | MM_MODEM_MODE_3G | MM_MODEM_MODE_2G),
                 .preferred = MM_MODEM_MODE_4G
             },
             {
-                .mode_str = "0302",
+                .mode_str = (gchar *) "0302",
                 .allowed = (MM_MODEM_MODE_4G | MM_MODEM_MODE_3G),
                 .preferred = MM_MODEM_MODE_4G
             },
             {
-                .mode_str = "03",
+                .mode_str = (gchar *) "03",
                 .allowed = MM_MODEM_MODE_4G,
                 .preferred = MM_MODEM_MODE_NONE
             },
@@ -829,7 +817,7 @@ static const SyscfgexTest syscfgex_tests[] = {
         "\r\n",
         {
             {
-                .mode_str = "03",
+                .mode_str = (gchar *) "03",
                 .allowed = MM_MODEM_MODE_4G,
                 .preferred = MM_MODEM_MODE_NONE
             },
@@ -845,27 +833,27 @@ static const SyscfgexTest syscfgex_tests[] = {
         "\r\n",
         {
             {
-                .mode_str = "00",
+                .mode_str = (gchar *) "00",
                 .allowed = (MM_MODEM_MODE_3G | MM_MODEM_MODE_2G),
                 .preferred = MM_MODEM_MODE_NONE
             },
             {
-                .mode_str = "01",
+                .mode_str = (gchar *) "01",
                 .allowed = MM_MODEM_MODE_2G,
                 .preferred = MM_MODEM_MODE_NONE
             },
             {
-                .mode_str = "02",
+                .mode_str = (gchar *) "02",
                 .allowed = MM_MODEM_MODE_3G,
                 .preferred = MM_MODEM_MODE_NONE
             },
             {
-                .mode_str = "0102",
+                .mode_str = (gchar *) "0102",
                 .allowed = (MM_MODEM_MODE_2G | MM_MODEM_MODE_3G),
                 .preferred = MM_MODEM_MODE_2G
             },
             {
-                .mode_str = "0201",
+                .mode_str = (gchar *) "0201",
                 .allowed = (MM_MODEM_MODE_2G | MM_MODEM_MODE_3G),
                 .preferred = MM_MODEM_MODE_3G
             }
@@ -896,20 +884,14 @@ test_syscfgex (void)
 
         for (j = 0; j < combinations->len; j++) {
             MMHuaweiSyscfgexCombination *single;
-            gchar *allowed_str;
-            gchar *preferred_str;
+            g_autofree gchar *allowed_str = NULL;
+            g_autofree gchar *preferred_str = NULL;
 
             single = &g_array_index (combinations, MMHuaweiSyscfgexCombination, j);
             allowed_str = mm_modem_mode_build_string_from_mask (single->allowed);
             preferred_str = mm_modem_mode_build_string_from_mask (single->preferred);
-            mm_dbg ("Test[%u], Combination[%u]: \"%s\", \"%s\", \"%s\"",
-                    i,
-                    j,
-                    single->mode_str,
-                    allowed_str,
-                    preferred_str);
-            g_free (allowed_str);
-            g_free (preferred_str);
+            mm_obj_dbg (NULL, "test[%u], combination[%u]: \"%s\", \"%s\", \"%s\"",
+                        i, j, single->mode_str, allowed_str, preferred_str);
         }
 
         for (j = 0; j < combinations->len; j++) {
@@ -1080,7 +1062,7 @@ typedef struct {
     gboolean ret;
     gboolean test_iso8601;
     gboolean test_tz;
-    gchar *iso8601;
+    const gchar *iso8601;
     gint32 offset;
     gint32 dst_offset;
     gint32 leap_seconds;
@@ -1169,7 +1151,7 @@ test_nwtime (void)
 typedef struct {
     const gchar *str;
     gboolean ret;
-    gchar *iso8601;
+    const gchar *iso8601;
 } TimeTest;
 
 static const TimeTest time_tests[] = {
@@ -1220,11 +1202,13 @@ typedef struct {
 } HcsqTest;
 
 static const HcsqTest hcsq_tests[] = {
-    { "^HCSQ:\"LTE\",30,19,66,0\r\n",  TRUE,  MM_MODEM_ACCESS_TECHNOLOGY_LTE,     30, 19,  66, 0, 0 },
-    { "^HCSQ: \"WCDMA\",30,30,58\r\n", TRUE,  MM_MODEM_ACCESS_TECHNOLOGY_UMTS,    30, 30,  58, 0, 0 },
-    { "^HCSQ: \"GSM\",36,255\r\n",     TRUE,  MM_MODEM_ACCESS_TECHNOLOGY_GSM,     36, 255,  0, 0, 0 },
-    { "^HCSQ: \"NOSERVICE\"\r\n",      FALSE, MM_MODEM_ACCESS_TECHNOLOGY_UNKNOWN,  0,   0,  0, 0, 0 },
-    { NULL,                            FALSE, MM_MODEM_ACCESS_TECHNOLOGY_UNKNOWN,  0,   0,  0, 0, 0 }
+    { "^HCSQ:\"LTE\",30,19,66,0\r\n",  TRUE,  MM_MODEM_ACCESS_TECHNOLOGY_LTE,     30, 19,   66,  0, 0 },
+    { "^HCSQ: \"WCDMA\",30,30,58\r\n", TRUE,  MM_MODEM_ACCESS_TECHNOLOGY_UMTS,    30, 30,   58,  0, 0 },
+    { "^HCSQ: \"GSM\",36,255\r\n",     TRUE,  MM_MODEM_ACCESS_TECHNOLOGY_GSM,     36, 255,   0,  0, 0 },
+    { "^HCSQ: LTE,33,40,135,11\r\n",   TRUE,  MM_MODEM_ACCESS_TECHNOLOGY_LTE,     33,  40, 135, 11, 0 },
+    { "^HCSQ: \"NOSERVICE\"\r\n",      FALSE, MM_MODEM_ACCESS_TECHNOLOGY_UNKNOWN,  0,   0,   0,  0, 0 },
+    { "^HCSQ: NOSERVICE\r\n",          FALSE, MM_MODEM_ACCESS_TECHNOLOGY_UNKNOWN,  0,   0,   0,  0, 0 },
+    { NULL,                            FALSE, MM_MODEM_ACCESS_TECHNOLOGY_UNKNOWN,  0,   0,   0,  0, 0 }
 };
 
 static void
@@ -1267,26 +1251,6 @@ test_hcsq (void)
 
 /*****************************************************************************/
 
-void
-_mm_log (const char *loc,
-         const char *func,
-         guint32 level,
-         const char *fmt,
-         ...)
-{
-    va_list args;
-    gchar *msg;
-
-    if (!g_test_verbose ())
-        return;
-
-    va_start (args, fmt);
-    msg = g_strdup_vprintf (fmt, args);
-    va_end (args);
-    g_print ("%s\n", msg);
-    g_free (msg);
-}
-
 int main (int argc, char **argv)
 {
     setlocale (LC_ALL, "");
