@@ -24,7 +24,7 @@
 #include <ctype.h>
 
 #include "ModemManager.h"
-#include "mm-log.h"
+#include "mm-log-object.h"
 #include "mm-errors-types.h"
 #include "mm-modem-helpers.h"
 #include "mm-base-modem-at.h"
@@ -77,7 +77,6 @@ load_unlock_retries_ready (MMBaseModem *self,
 
     response = mm_base_modem_at_command_finish (MM_BASE_MODEM (self), res, &error);
     if (!response) {
-        mm_dbg ("Couldn't query unlock retries: '%s'", error->message);
         g_task_return_error (task, error);
         g_object_unref (task);
         return;
@@ -190,7 +189,6 @@ get_supported_modes_ready (MMBaseModem *self,
 
     response = mm_base_modem_at_command_finish (MM_BASE_MODEM (self), res, &error);
     if (!response) {
-        mm_dbg ("Fail to get response");
         g_task_return_error (task, error);
         g_object_unref (task);
         return;
@@ -382,7 +380,7 @@ load_current_modes_finish (MMIfaceModem *self,
             break;
         default:
             result = FALSE;
-            mm_dbg ("Not supported allowed mode %d", erat_mode);
+            mm_obj_dbg (self, "unsupported allowed mode reported in +ERAT: %d", erat_mode);
             goto done;
     }
 
@@ -401,7 +399,7 @@ load_current_modes_finish (MMIfaceModem *self,
             break;
         default:
             result = FALSE;
-            mm_dbg ("Not supported preferred mode %d", erat_pref);
+            mm_obj_dbg (self, "unsupported preferred mode %d", erat_pref);
             goto done;
     }
 
@@ -545,10 +543,10 @@ mtk_80_signal_changed (MMPortSerialAt *port,
     if (quality == 99)
         quality = 0;
     else
-        quality = CLAMP(quality, 0, 31) * 100 / 31;
+        quality = MM_CLAMP_HIGH (quality, 31) * 100 / 31;
 
-    mm_dbg ("6280 signal quality URC received: quality = %u", quality);
-    mm_iface_modem_update_signal_quality (MM_IFACE_MODEM (self), (guint)quality);
+    mm_obj_dbg (self, "6280 signal quality URC received: %u", quality);
+    mm_iface_modem_update_signal_quality (MM_IFACE_MODEM (self), quality);
 }
 
 static void
@@ -564,10 +562,10 @@ mtk_90_2g_signal_changed (MMPortSerialAt *port,
     if (quality == 99)
         quality = 0;
     else
-        quality = CLAMP (quality, 0, 63) * 100 / 63;
+        quality = MM_CLAMP_HIGH (quality, 63) * 100 / 63;
 
-    mm_dbg ("2G signal quality URC received: quality = %u", quality);
-    mm_iface_modem_update_signal_quality (MM_IFACE_MODEM (self), (guint)quality);
+    mm_obj_dbg (self, "2G signal quality URC received: %u", quality);
+    mm_iface_modem_update_signal_quality (MM_IFACE_MODEM (self), quality);
 }
 
 static void
@@ -580,10 +578,10 @@ mtk_90_3g_signal_changed (MMPortSerialAt *port,
     if (!mm_get_uint_from_match_info (match_info, 1, &quality))
         return;
 
-    quality = CLAMP (quality, 0, 96) * 100 / 96;
+    quality = MM_CLAMP_HIGH (quality, 96) * 100 / 96;
 
-    mm_dbg ("3G signal quality URC received: quality = %u", quality);
-    mm_iface_modem_update_signal_quality (MM_IFACE_MODEM (self), (guint)quality);
+    mm_obj_dbg (self, "3G signal quality URC received: %u", quality);
+    mm_iface_modem_update_signal_quality (MM_IFACE_MODEM (self), quality);
 }
 
 static void
@@ -596,10 +594,10 @@ mtk_90_4g_signal_changed (MMPortSerialAt *port,
     if (!mm_get_uint_from_match_info (match_info, 1, &quality))
         return;
 
-    quality = CLAMP (quality, 0, 97) * 100 / 97;
+    quality = MM_CLAMP_HIGH (quality, 97) * 100 / 97;
 
-    mm_dbg ("4G signal quality URC received: quality = %u", quality);
-    mm_iface_modem_update_signal_quality (MM_IFACE_MODEM (self), (guint)quality);
+    mm_obj_dbg (self, "4G signal quality URC received: %u", quality);
+    mm_iface_modem_update_signal_quality (MM_IFACE_MODEM (self), quality);
 }
 
 static void
@@ -724,14 +722,14 @@ modem_3gpp_cleanup_unsolicited_events (MMIfaceModem3gpp *self,
 
 static const MMBaseModemAtCommand unsolicited_enable_sequence[] = {
     /* enable signal URC */
-    {"+ECSQ=2", 5, FALSE, NULL},
-    {NULL}
+    { "+ECSQ=2", 5, FALSE, NULL },
+    { NULL }
 };
 
 static const MMBaseModemAtCommand unsolicited_disable_sequence[] = {
     /* disable signal URC */
-    {"+ECSQ=0", 5, FALSE, NULL},
-    {NULL}
+    { "+ECSQ=0" , 5, FALSE, NULL },
+    { NULL }
 };
 
 static void
