@@ -21,7 +21,7 @@
 #define _LIBMM_INSIDE_MM
 #include <libmm-glib.h>
 
-#include "mm-log.h"
+#include "mm-log-object.h"
 #include "mm-plugin-simtech.h"
 #include "mm-broadband-modem-simtech.h"
 
@@ -47,7 +47,7 @@ create_modem (MMPlugin *self,
 {
 #if defined WITH_QMI
     if (mm_port_probe_list_has_qmi_port (probes)) {
-        mm_dbg ("QMI-powered SimTech modem found...");
+        mm_obj_dbg (self, "QMI-powered SimTech modem found...");
         return MM_BASE_MODEM (mm_broadband_modem_qmi_simtech_new (uid,
                                                                   drivers,
                                                                   mm_plugin_get_name (self),
@@ -74,7 +74,7 @@ mm_plugin_create (void)
 
     return MM_PLUGIN (
         g_object_new (MM_TYPE_PLUGIN_SIMTECH,
-                      MM_PLUGIN_NAME,               "SimTech",
+                      MM_PLUGIN_NAME,               MM_MODULE_NAME,
                       MM_PLUGIN_ALLOWED_SUBSYSTEMS, subsystems,
                       MM_PLUGIN_ALLOWED_VENDOR_IDS, vendor_ids,
                       MM_PLUGIN_ALLOWED_AT,         TRUE,
