@@ -19,9 +19,10 @@
 #include <glib.h>
 
 /* AT+CPMS=? (Preferred SMS storage) response parser */
-gboolean mm_thuraya_3gpp_parse_cpms_test_response (const gchar *reply,
-                                                   GArray **mem1,
-                                                   GArray **mem2,
-                                                   GArray **mem3);
+gboolean mm_thuraya_3gpp_parse_cpms_test_response (const gchar  *reply,
+                                                   GArray      **mem1,
+                                                   GArray      **mem2,
+                                                   GArray      **mem3,
+                                                   GError      **error);
 
 #endif  /* MM_MODEM_HELPERS_THURAYA_H */
