@@ -22,7 +22,7 @@
 #define _LIBMM_INSIDE_MM
 #include <libmm-glib.h>
 
-#include "mm-log.h"
+#include "mm-log-object.h"
 #include "mm-iface-modem.h"
 #include "mm-iface-modem-signal.h"
 #include "mm-iface-modem-location.h"
@@ -154,6 +154,7 @@ xact_test_ready (MMBaseModem  *self,
     response = mm_base_modem_at_command_finish (self, res, &error);
     if (!response ||
         !mm_xmm_parse_xact_test_response (response,
+                                          self,
                                           &priv->supported_modes,
                                           &priv->supported_bands,
                                           &error))
@@ -419,7 +420,8 @@ xact_set_bands_ready (MMBaseModem  *self,
 }
 
 static gchar *
-validate_and_build_command_set_current_bands (const GArray *bands_array,
+validate_and_build_command_set_current_bands (MMSharedXmm  *self,
+                                              const GArray *bands_array,
                                               const GArray *supported_modes,
                                               MMModemMode   allowed_modes,
                                               GError      **error)
@@ -444,11 +446,10 @@ validate_and_build_command_set_current_bands (const GArray *bands_array,
          */
         unapplied = mm_xmm_get_modem_mode_any (supported_modes) & ~(allowed_modes);
         if (unapplied != MM_MODEM_MODE_NONE) {
-            gchar *str;
+            g_autofree gchar *str = NULL;
 
             str = mm_modem_mode_build_string_from_mask (unapplied);
-            mm_warn ("Automatic band selection not applied to non-current modes %s", str);
-            g_free (str);
+            mm_obj_warn (self, "automatic band selection not applied to non-current modes %s", str);
         }
 
         /* Nothing else to validate, go build the command right away */
@@ -508,7 +509,7 @@ validate_and_build_command_set_current_bands (const GArray *bands_array,
     if (unapplied_bands->len > 0) {
         gchar *str;
 
-        str = mm_common_build_bands_string ((const MMModemBand *)unapplied_bands->data, unapplied_bands->len);
+        str = mm_common_build_bands_string ((const MMModemBand *)(gconstpointer)unapplied_bands->data, unapplied_bands->len);
         inner_error = g_error_new (MM_CORE_ERROR, MM_CORE_ERROR_INVALID_ARGS,
                                    "Cannot update bands for modes not currently allowed: %s", str);
         g_free (str);
@@ -549,7 +550,8 @@ mm_shared_xmm_set_current_bands (MMIfaceModem        *self,
         goto out;
     }
 
-    command = validate_and_build_command_set_current_bands (bands_array,
+    command = validate_and_build_command_set_current_bands (MM_SHARED_XMM (self),
+                                                            bands_array,
                                                             priv->supported_modes,
                                                             priv->allowed_modes,
                                                             &error);
@@ -764,7 +766,7 @@ mm_shared_xmm_signal_load_values_finish (MMIfaceModemSignal  *self,
     const gchar *response;
 
     response = mm_base_modem_at_command_finish (MM_BASE_MODEM (self), res, error);
-    if (!response || !mm_xmm_xcesq_response_to_signal_info (response, gsm, umts, lte, error))
+    if (!response || !mm_xmm_xcesq_response_to_signal_info (response, self, gsm, umts, lte, error))
         return FALSE;
 
     if (cdma)
@@ -839,28 +841,28 @@ xlcslsr_test_ready (MMBaseModem  *self,
                                              &loc_response_type_nmea_supported,
                                              &gnss_type_gps_glonass_supported,
                                              &error)) {
-        mm_dbg ("XLCSLSR based GPS control unsupported: %s", error->message);
+        mm_obj_dbg (self, "XLCSLSR based GPS control unsupported: %s", error->message);
         g_clear_error (&error);
     } else if (!transport_protocol_invalid_supported ||
                !standalone_position_mode_supported ||
                !loc_response_type_nmea_supported ||
                !gnss_type_gps_glonass_supported) {
-        mm_dbg ("XLCSLSR based GPS control unsupported: protocol invalid %s, standalone %s, nmea %s, gps/glonass %s",
-                transport_protocol_invalid_supported ? "supported" : "unsupported",
-                standalone_position_mode_supported   ? "supported" : "unsupported",
-                loc_response_type_nmea_supported     ? "supported" : "unsupported",
-                gnss_type_gps_glonass_supported      ? "supported" : "unsupported");
+        mm_obj_dbg (self, "XLCSLSR based GPS control unsupported: protocol invalid %s, standalone %s, nmea %s, gps/glonass %s",
+                    transport_protocol_invalid_supported ? "supported" : "unsupported",
+                    standalone_position_mode_supported   ? "supported" : "unsupported",
+                    loc_response_type_nmea_supported     ? "supported" : "unsupported",
+                    gnss_type_gps_glonass_supported      ? "supported" : "unsupported");
     } else {
-        mm_dbg ("XLCSLSR based GPS control supported");
+        mm_obj_dbg (self, "XLCSLSR based GPS control supported");
         priv->supported_sources |= (MM_MODEM_LOCATION_SOURCE_GPS_NMEA | MM_MODEM_LOCATION_SOURCE_GPS_RAW);
 
         if (transport_protocol_supl_supported && ms_assisted_based_position_mode_supported) {
-            mm_dbg ("XLCSLSR based A-GPS control supported");
+            mm_obj_dbg (self, "XLCSLSR based A-GPS control supported");
             priv->supported_sources |= (MM_MODEM_LOCATION_SOURCE_AGPS_MSA | MM_MODEM_LOCATION_SOURCE_AGPS_MSB);
         } else {
-            mm_dbg ("XLCSLSR based A-GPS control unsupported: protocol supl %s, ms assisted/based %s",
-                    transport_protocol_supl_supported         ? "supported" : "unsupported",
-                    ms_assisted_based_position_mode_supported ? "supported" : "unsupported");
+            mm_obj_dbg (self, "XLCSLSR based A-GPS control unsupported: protocol supl %s, ms assisted/based %s",
+                        transport_protocol_supl_supported         ? "supported" : "unsupported",
+                        ms_assisted_based_position_mode_supported ? "supported" : "unsupported");
         }
 
         sources |= priv->supported_sources;
@@ -902,7 +904,7 @@ parent_load_capabilities_ready (MMIfaceModemLocation *self,
 
     /* If parent already supports GPS sources, we won't do anything else */
     if (sources & (MM_MODEM_LOCATION_SOURCE_GPS_NMEA | MM_MODEM_LOCATION_SOURCE_GPS_RAW)) {
-        mm_dbg ("No need to run XLCSLSR based location gathering");
+        mm_obj_dbg (self, "no need to run XLCSLSR based location gathering");
         g_task_return_int (task, sources);
         g_object_unref (task);
         return;
@@ -950,47 +952,6 @@ nmea_received (MMPortSerialAt *port,
     gchar *trace;
 
     trace = g_match_info_fetch (info, 1);
-
-    /* Helper to debug GPS location related issues. Don't depend on a real GPS
-     * fix for debugging, just use some random values to update */
-#if 0
-    {
-        const gchar *prefix = NULL;
-        const gchar *lat = NULL;
-
-        /* lat N/S just to test which one is used */
-        if (g_str_has_prefix (trace, "$GPGGA")) {
-            prefix = "GPGGA";
-            lat = "S";
-        } else if (g_str_has_prefix (trace, "$GNGGA")) {
-            prefix = "GNGGA";
-            lat = "N";
-        }
-
-        if (prefix && lat) {
-            GString *str;
-            GDateTime *now;
-
-            mm_dbg ("GGA trace detected: '%s'", trace);
-            g_free (trace);
-
-            now = g_date_time_new_now_utc ();
-            str = g_string_new ("");
-            g_string_append_printf (str,
-                                    "$%s,%02u%02u%02u,4807.038,%s,01131.000,E,1,08,0.9,545.4,M,46.9,M,,*47",
-                                    prefix,
-                                    g_date_time_get_hour (now),
-                                    g_date_time_get_minute (now),
-                                    g_date_time_get_second (now),
-                                    lat);
-            mm_iface_modem_location_gps_update (MM_IFACE_MODEM_LOCATION (self), str->str);
-            g_string_free (str, TRUE);
-            g_date_time_unref (now);
-            return;
-        }
-    }
-#endif
-
     mm_iface_modem_location_gps_update (MM_IFACE_MODEM_LOCATION (self), trace);
     g_free (trace);
 }
@@ -1078,6 +1039,7 @@ gps_engine_start (GTask *task)
             transport_protocol = 1;
             pos_mode = 2;
             break;
+        case GPS_ENGINE_STATE_OFF:
         default:
             g_assert_not_reached ();
             break;
@@ -1260,7 +1222,7 @@ parent_disable_location_gathering_ready (MMIfaceModemLocation *self,
                                          GAsyncResult         *res,
                                          GTask                *task)
 {
-    GError  *error;
+    GError  *error = NULL;
     Private *priv;
 
     priv = get_private (MM_SHARED_XMM (self));
@@ -1359,7 +1321,7 @@ parent_enable_location_gathering_ready (MMIfaceModemLocation *self,
                                         GAsyncResult         *res,
                                         GTask                *task)
 {
-    GError  *error;
+    GError  *error = NULL;
     Private *priv;
 
     priv = get_private (MM_SHARED_XMM (self));
