@@ -31,7 +31,7 @@
 #include "mm-bearer-qmi.h"
 #include "mm-modem-helpers-qmi.h"
 #include "mm-port-enums-types.h"
-#include "mm-log.h"
+#include "mm-log-object.h"
 #include "mm-modem-helpers.h"
 
 G_DEFINE_TYPE (MMBearerQmi, mm_bearer_qmi, MM_TYPE_BASE_BEARER)
@@ -164,8 +164,8 @@ reload_stats_context_step (GTask *task)
 
     switch (ctx->step) {
     case RELOAD_STATS_CONTEXT_STEP_FIRST:
-        /* Fall through */
         ctx->step++;
+        /* fall through */
     case RELOAD_STATS_CONTEXT_STEP_IPV4:
         if (self->priv->client_ipv4) {
             qmi_client_wds_get_packet_statistics (QMI_CLIENT_WDS (self->priv->client_ipv4),
@@ -177,7 +177,7 @@ reload_stats_context_step (GTask *task)
             return;
         }
         ctx->step++;
-        /* Fall through */
+        /* fall through */
     case RELOAD_STATS_CONTEXT_STEP_IPV6:
         if (self->priv->client_ipv6) {
             qmi_client_wds_get_packet_statistics (QMI_CLIENT_WDS (self->priv->client_ipv6),
@@ -189,13 +189,16 @@ reload_stats_context_step (GTask *task)
             return;
         }
         ctx->step++;
-        /* Fall through */
+        /* fall through */
     case RELOAD_STATS_CONTEXT_STEP_LAST:
         g_task_return_pointer (task,
                                g_memdup (&ctx->stats, sizeof (ctx->stats)),
                                g_free);
         g_object_unref (task);
         return;
+
+    default:
+        g_assert_not_reached ();
     }
 }
 
@@ -326,7 +329,7 @@ connection_status_context_step (GTask *task)
                 return;
             }
             ctx->step++;
-            /* fall down to next step */
+            /* fall through */
 
         case CONNECTION_STATUS_CONTEXT_STEP_IPV4:
             if (self->priv->client_ipv4) {
@@ -339,7 +342,7 @@ connection_status_context_step (GTask *task)
                 return;
             }
             ctx->step++;
-            /* fall down to next step */
+            /* fall through */
 
         case CONNECTION_STATUS_CONTEXT_STEP_IPV6:
             if (self->priv->client_ipv6) {
@@ -352,13 +355,16 @@ connection_status_context_step (GTask *task)
                 return;
             }
             ctx->step++;
-            /* fall down to next step */
+            /* fall through */
 
         case CONNECTION_STATUS_CONTEXT_STEP_LAST:
             /* All available clients are connected */
             g_task_return_int (task, MM_BEARER_CONNECTION_STATUS_CONNECTED);
             g_object_unref (task);
             return;
+
+        default:
+            g_assert_not_reached ();
     }
 }
 
@@ -457,36 +463,55 @@ connect_context_free (ConnectContext *ctx)
     g_free (ctx->user);
     g_free (ctx->password);
 
-    if (ctx->packet_service_status_ipv4_indication_id) {
-        common_setup_cleanup_packet_service_status_unsolicited_events (ctx->self,
-                                                                       ctx->client_ipv4,
-                                                                       FALSE,
-                                                                       &ctx->packet_service_status_ipv4_indication_id);
+    if (ctx->client_ipv4) {
+        if (ctx->packet_service_status_ipv4_indication_id) {
+            common_setup_cleanup_packet_service_status_unsolicited_events (ctx->self,
+                                                                           ctx->client_ipv4,
+                                                                           FALSE,
+                                                                           &ctx->packet_service_status_ipv4_indication_id);
+        }
+        if (ctx->event_report_ipv4_indication_id) {
+            cleanup_event_report_unsolicited_events (ctx->self,
+                                                     ctx->client_ipv4,
+                                                     &ctx->event_report_ipv4_indication_id);
+        }
+        if (ctx->packet_data_handle_ipv4) {
+            g_autoptr(QmiMessageWdsStopNetworkInput) input = NULL;
+
+            input = qmi_message_wds_stop_network_input_new ();
+            qmi_message_wds_stop_network_input_set_packet_data_handle (input, ctx->packet_data_handle_ipv4, NULL);
+            qmi_client_wds_stop_network (ctx->client_ipv4, input, 30, NULL, NULL, NULL);
+        }
+        g_clear_object (&ctx->client_ipv4);
     }
-    if (ctx->event_report_ipv4_indication_id) {
-        cleanup_event_report_unsolicited_events (ctx->self,
-                                                 ctx->client_ipv4,
-                                                 &ctx->event_report_ipv4_indication_id);
-    }
-    if (ctx->packet_service_status_ipv6_indication_id) {
-        common_setup_cleanup_packet_service_status_unsolicited_events (ctx->self,
-                                                                       ctx->client_ipv6,
-                                                                       FALSE,
-                                                                       &ctx->packet_service_status_ipv6_indication_id);
-    }
-    if (ctx->event_report_ipv6_indication_id) {
-        cleanup_event_report_unsolicited_events (ctx->self,
-                                                 ctx->client_ipv6,
-                                                 &ctx->event_report_ipv6_indication_id);
+
+    if (ctx->client_ipv6) {
+        if (ctx->packet_service_status_ipv6_indication_id) {
+            common_setup_cleanup_packet_service_status_unsolicited_events (ctx->self,
+                                                                           ctx->client_ipv6,
+                                                                           FALSE,
+                                                                           &ctx->packet_service_status_ipv6_indication_id);
+        }
+        if (ctx->event_report_ipv6_indication_id) {
+            cleanup_event_report_unsolicited_events (ctx->self,
+                                                     ctx->client_ipv6,
+                                                     &ctx->event_report_ipv6_indication_id);
+        }
+        if (ctx->packet_data_handle_ipv6) {
+            g_autoptr(QmiMessageWdsStopNetworkInput) input = NULL;
+
+            input = qmi_message_wds_stop_network_input_new ();
+            qmi_message_wds_stop_network_input_set_packet_data_handle (input, ctx->packet_data_handle_ipv6, NULL);
+            qmi_client_wds_stop_network (ctx->client_ipv6, input, 30, NULL, NULL, NULL);
+        }
+        g_clear_object (&ctx->client_ipv6);
     }
 
     if (ctx->explicit_qmi_open)
-        mm_port_qmi_close (ctx->qmi);
+        mm_port_qmi_close (ctx->qmi, NULL, NULL);
 
     g_clear_error (&ctx->error_ipv4);
     g_clear_error (&ctx->error_ipv6);
-    g_clear_object (&ctx->client_ipv4);
-    g_clear_object (&ctx->client_ipv6);
     g_clear_object (&ctx->ipv4_config);
     g_clear_object (&ctx->ipv6_config);
     g_object_unref (ctx->data);
@@ -531,11 +556,14 @@ start_network_ready (QmiClientWds *client,
                      GAsyncResult *res,
                      GTask *task)
 {
+    MMBearerQmi *self;
     ConnectContext *ctx;
     GError *error = NULL;
     QmiMessageWdsStartNetworkOutput *output;
 
-    ctx = g_task_get_task_data (task);
+    self = g_task_get_source_object (task);
+    ctx  = g_task_get_task_data (task);
+
     g_assert (ctx->running_ipv4 || ctx->running_ipv6);
     g_assert (!(ctx->running_ipv4 && ctx->running_ipv6));
 
@@ -559,7 +587,7 @@ start_network_ready (QmiClientWds *client,
 
             /* Fall down to a successful connection */
         } else {
-            mm_info ("error: couldn't start network: %s", error->message);
+            mm_obj_info (self, "couldn't start network: %s", error->message);
             if (g_error_matches (error,
                                  QMI_PROTOCOL_ERROR,
                                  QMI_PROTOCOL_ERROR_CALL_FAILED)) {
@@ -571,20 +599,18 @@ start_network_ready (QmiClientWds *client,
                         output,
                         &cer,
                         NULL))
-                    mm_info ("call end reason (%u): '%s'",
-                             cer,
-                             qmi_wds_call_end_reason_get_string (cer));
+                    mm_obj_info (self, "call end reason (%u): %s", cer, qmi_wds_call_end_reason_get_string (cer));
 
                 if (qmi_message_wds_start_network_output_get_verbose_call_end_reason (
                         output,
                         &verbose_cer_type,
                         &verbose_cer_reason,
                         NULL))
-                    mm_info ("verbose call end reason (%u,%d): [%s] %s",
-                             verbose_cer_type,
-                             verbose_cer_reason,
-                             qmi_wds_verbose_call_end_reason_type_get_string (verbose_cer_type),
-                             qmi_wds_verbose_call_end_reason_get_string (verbose_cer_type, verbose_cer_reason));
+                    mm_obj_info (self, "verbose call end reason (%u,%d): [%s] %s",
+                                 verbose_cer_type,
+                                 verbose_cer_reason,
+                                 qmi_wds_verbose_call_end_reason_type_get_string (verbose_cer_type),
+                                 qmi_wds_verbose_call_end_reason_get_string (verbose_cer_type, verbose_cer_reason));
             }
         }
     }
@@ -687,7 +713,7 @@ get_ipv4_config (MMBearerQmi *self,
 
     /* IPv4 subnet mask */
     if (!qmi_message_wds_get_current_settings_output_get_ipv4_gateway_subnet_mask (output, &addr, &error)) {
-        mm_warn ("Failed to read IPv4 netmask (%s)", error->message);
+        mm_obj_warn (self, "failed to read IPv4 netmask: %s", error->message);
         g_clear_error (&error);
         return NULL;
     }
@@ -696,12 +722,12 @@ get_ipv4_config (MMBearerQmi *self,
 
     /* IPv4 address */
     if (!qmi_message_wds_get_current_settings_output_get_ipv4_address (output, &addr, &error)) {
-        mm_warn ("IPv4 family but no IPv4 address (%s)", error->message);
+        mm_obj_warn (self, "IPv4 family but no IPv4 address: %s", error->message);
         g_clear_error (&error);
         return NULL;
     }
 
-    mm_info ("QMI IPv4 Settings:");
+    mm_obj_info (self, "QMI IPv4 Settings:");
 
     config = mm_bearer_ip_config_new ();
     mm_bearer_ip_config_set_method (config, ip_method);
@@ -710,15 +736,15 @@ get_ipv4_config (MMBearerQmi *self,
     qmi_inet4_ntop (addr, buf, sizeof (buf));
     mm_bearer_ip_config_set_address (config, buf);
     mm_bearer_ip_config_set_prefix (config, prefix);
-    mm_info ("    Address: %s/%d", buf, prefix);
+    mm_obj_info (self, "    address: %s/%d", buf, prefix);
 
     /* IPv4 gateway address */
     if (qmi_message_wds_get_current_settings_output_get_ipv4_gateway_address (output, &addr, &error)) {
         qmi_inet4_ntop (addr, buf, sizeof (buf));
         mm_bearer_ip_config_set_gateway (config, buf);
-        mm_info ("    Gateway: %s", buf);
+        mm_obj_info (self, "    gateway: %s", buf);
     } else {
-        mm_info ("    Gateway: failed (%s)", error->message);
+        mm_obj_info (self, "    gateway: failed (%s)", error->message);
         g_clear_error (&error);
     }
 
@@ -726,9 +752,9 @@ get_ipv4_config (MMBearerQmi *self,
     if (qmi_message_wds_get_current_settings_output_get_primary_ipv4_dns_address (output, &addr, &error)) {
         qmi_inet4_ntop (addr, buf, sizeof (buf));
         dns[dns_idx++] = buf;
-        mm_info ("    DNS #1: %s", buf);
+        mm_obj_info (self, "    DNS #1: %s", buf);
     } else {
-        mm_info ("    DNS #1: failed (%s)", error->message);
+        mm_obj_info (self, "    DNS #1: failed (%s)", error->message);
         g_clear_error (&error);
     }
 
@@ -736,9 +762,9 @@ get_ipv4_config (MMBearerQmi *self,
     if (qmi_message_wds_get_current_settings_output_get_secondary_ipv4_dns_address (output, &addr, &error)) {
         qmi_inet4_ntop (addr, buf2, sizeof (buf2));
         dns[dns_idx++] = buf2;
-        mm_info ("    DNS #2: %s", buf2);
+        mm_obj_info (self, "    DNS #2: %s", buf2);
     } else {
-        mm_info ("    DNS #2: failed (%s)", error->message);
+        mm_obj_info (self, "    DNS #2: failed (%s)", error->message);
         g_clear_error (&error);
     }
 
@@ -747,7 +773,7 @@ get_ipv4_config (MMBearerQmi *self,
 
     if (mtu) {
         mm_bearer_ip_config_set_mtu (config, mtu);
-        mm_info ("       MTU: %d", mtu);
+        mm_obj_info (self, "       MTU: %d", mtu);
     }
 
     return config;
@@ -789,12 +815,12 @@ get_ipv6_config (MMBearerQmi *self,
 
     /* If the message has an IPv6 address, create an IPv6 bearer config */
     if (!qmi_message_wds_get_current_settings_output_get_ipv6_address (output, &array, &prefix, &error)) {
-        mm_warn ("IPv6 family but no IPv6 address (%s)", error->message);
+        mm_obj_warn (self, "IPv6 family but no IPv6 address: %s", error->message);
         g_clear_error (&error);
         return NULL;
     }
 
-    mm_info ("QMI IPv6 Settings:");
+    mm_obj_info (self, "QMI IPv6 Settings:");
 
     config = mm_bearer_ip_config_new ();
     mm_bearer_ip_config_set_method (config, ip_method);
@@ -804,15 +830,15 @@ get_ipv6_config (MMBearerQmi *self,
 
     mm_bearer_ip_config_set_address (config, buf);
     mm_bearer_ip_config_set_prefix (config, prefix);
-    mm_info ("    Address: %s/%d", buf, prefix);
+    mm_obj_info (self, "    address: %s/%d", buf, prefix);
 
     /* IPv6 gateway address */
     if (qmi_message_wds_get_current_settings_output_get_ipv6_gateway_address (output, &array, &prefix, &error)) {
         qmi_inet6_ntop (array, buf, sizeof (buf));
         mm_bearer_ip_config_set_gateway (config, buf);
-        mm_info ("    Gateway: %s/%d", buf, prefix);
+        mm_obj_info (self, "    gateway: %s/%d", buf, prefix);
     } else {
-        mm_info ("    Gateway: failed (%s)", error->message);
+        mm_obj_info (self, "    gateway: failed (%s)", error->message);
         g_clear_error (&error);
     }
 
@@ -820,9 +846,9 @@ get_ipv6_config (MMBearerQmi *self,
     if (qmi_message_wds_get_current_settings_output_get_ipv6_primary_dns_address (output, &array, &error)) {
         qmi_inet6_ntop (array, buf, sizeof (buf));
         dns[dns_idx++] = buf;
-        mm_info ("    DNS #1: %s", buf);
+        mm_obj_info (self, "    DNS #1: %s", buf);
     } else {
-        mm_info ("    DNS #1: failed (%s)", error->message);
+        mm_obj_info (self, "    DNS #1: failed (%s)", error->message);
         g_clear_error (&error);
     }
 
@@ -830,9 +856,9 @@ get_ipv6_config (MMBearerQmi *self,
     if (qmi_message_wds_get_current_settings_output_get_ipv6_secondary_dns_address (output, &array, &error)) {
         qmi_inet6_ntop (array, buf2, sizeof (buf2));
         dns[dns_idx++] = buf2;
-        mm_info ("    DNS #2: %s", buf2);
+        mm_obj_info (self, "    DNS #2: %s", buf2);
     } else {
-        mm_info ("    DNS #2: failed (%s)", error->message);
+        mm_obj_info (self, "    DNS #2: failed (%s)", error->message);
         g_clear_error (&error);
     }
 
@@ -841,7 +867,7 @@ get_ipv6_config (MMBearerQmi *self,
 
     if (mtu) {
         mm_bearer_ip_config_set_mtu (config, mtu);
-        mm_info ("       MTU: %d", mtu);
+        mm_obj_info (self, "       MTU: %d", mtu);
     }
 
     return config;
@@ -852,11 +878,13 @@ get_current_settings_ready (QmiClientWds *client,
                             GAsyncResult *res,
                             GTask *task)
 {
+    MMBearerQmi *self;
     ConnectContext *ctx;
     GError *error = NULL;
     QmiMessageWdsGetCurrentSettingsOutput *output;
 
-    ctx = g_task_get_task_data (task);
+    self = g_task_get_source_object (task);
+    ctx  = g_task_get_task_data (task);
     g_assert (ctx->running_ipv4 || ctx->running_ipv6);
 
     output = qmi_client_wds_get_current_settings_finish (client, res, &error);
@@ -865,7 +893,7 @@ get_current_settings_ready (QmiClientWds *client,
 
         /* When we're using static IP address, the current settings are mandatory */
         if (ctx->ip_method == MM_BEARER_IP_METHOD_STATIC) {
-            mm_warn ("Failed to retrieve mandatory IP settings: %s", error->message);
+            mm_obj_warn (self, "failed to retrieve mandatory IP settings: %s", error->message);
             if (output)
                 qmi_message_wds_get_current_settings_output_unref (output);
             complete_connect (task, NULL, error);
@@ -873,7 +901,7 @@ get_current_settings_ready (QmiClientWds *client,
         }
 
         /* Otherwise, just go on as we're asking for DHCP */
-        mm_dbg ("Couldn't get current settings: %s", error->message);
+        mm_obj_dbg (self, "couldn't get current settings: %s", error->message);
         g_error_free (error);
 
         config = mm_bearer_ip_config_new ();
@@ -891,16 +919,16 @@ get_current_settings_ready (QmiClientWds *client,
         GArray *array;
 
         if (!qmi_message_wds_get_current_settings_output_get_ip_family (output, &ip_family, &error)) {
-            mm_dbg (" IP Family: failed (%s); assuming IPv4", error->message);
+            mm_obj_dbg (self, " IP Family: failed (%s); assuming IPv4", error->message);
             g_clear_error (&error);
             ip_family = QMI_WDS_IP_FAMILY_IPV4;
         }
-        mm_dbg (" IP Family: %s",
+        mm_obj_dbg (self, " IP Family: %s",
                 (ip_family == QMI_WDS_IP_FAMILY_IPV4) ? "IPv4" :
                    (ip_family == QMI_WDS_IP_FAMILY_IPV6) ? "IPv6" : "unknown");
 
         if (!qmi_message_wds_get_current_settings_output_get_mtu (output, &mtu, &error)) {
-            mm_dbg ("       MTU: failed (%s)", error->message);
+            mm_obj_dbg (self, "       MTU: failed (%s)", error->message);
             g_clear_error (&error);
         }
 
@@ -919,10 +947,10 @@ get_current_settings_ready (QmiClientWds *client,
                     g_string_append (s, ", ");
                 g_string_append (s, g_array_index (array, const char *, i));
             }
-            mm_dbg ("   Domains: %s", s->str);
+            mm_obj_dbg (self, "   domains: %s", s->str);
             g_string_free (s, TRUE);
         } else {
-            mm_dbg ("   Domains: failed (%s)", error ? error->message : "unknown");
+            mm_obj_dbg (self, "   domains: failed (%s)", error ? error->message : "unknown");
             g_clear_error (&error);
         }
     }
@@ -969,11 +997,14 @@ set_ip_family_ready (QmiClientWds *client,
                      GAsyncResult *res,
                      GTask *task)
 {
+    MMBearerQmi *self;
     ConnectContext *ctx;
     GError *error = NULL;
     QmiMessageWdsSetIpFamilyOutput *output;
 
+    self = g_task_get_source_object (task);
     ctx = g_task_get_task_data (task);
+
     g_assert (ctx->running_ipv4 || ctx->running_ipv6);
     g_assert (!(ctx->running_ipv4 && ctx->running_ipv6));
 
@@ -985,7 +1016,7 @@ set_ip_family_ready (QmiClientWds *client,
 
     if (error) {
         /* Ensure we add the IP family preference TLV */
-        mm_dbg ("Couldn't set IP family preference: '%s'", error->message);
+        mm_obj_dbg (self, "couldn't set IP family preference: %s", error->message);
         g_error_free (error);
         ctx->default_ip_family_set = FALSE;
     } else {
@@ -1023,20 +1054,18 @@ packet_service_status_indication_cb (QmiClientWds *client,
                     output,
                     &cer,
                     NULL))
-                mm_info ("bearer call end reason (%u): '%s'",
-                         cer,
-                         qmi_wds_call_end_reason_get_string (cer));
+                mm_obj_info (self, "bearer call end reason (%u): '%s'", cer, qmi_wds_call_end_reason_get_string (cer));
 
             if (qmi_indication_wds_packet_service_status_output_get_verbose_call_end_reason (
                     output,
                     &verbose_cer_type,
                     &verbose_cer_reason,
                     NULL))
-                mm_info ("bearer verbose call end reason (%u,%d): [%s] %s",
-                         verbose_cer_type,
-                         verbose_cer_reason,
-                         qmi_wds_verbose_call_end_reason_type_get_string (verbose_cer_type),
-                         qmi_wds_verbose_call_end_reason_get_string (verbose_cer_type, verbose_cer_reason));
+                mm_obj_info (self, "bearer verbose call end reason (%u,%d): [%s] %s",
+                             verbose_cer_type,
+                             verbose_cer_reason,
+                             qmi_wds_verbose_call_end_reason_type_get_string (verbose_cer_type),
+                             qmi_wds_verbose_call_end_reason_get_string (verbose_cer_type, verbose_cer_reason));
 
             mm_base_bearer_report_connection_status (MM_BASE_BEARER (self), MM_BEARER_CONNECTION_STATUS_DISCONNECTED);
         }
@@ -1071,7 +1100,7 @@ event_report_indication_cb (QmiClientWds *client,
                             QmiIndicationWdsEventReportOutput *output,
                             MMBearerQmi *self)
 {
-    mm_dbg ("Got QMI WDS event report");
+    mm_obj_dbg (self, "got QMI WDS event report");
 }
 
 static guint
@@ -1289,11 +1318,9 @@ connect_context_step (GTask *task)
 
     switch (ctx->step) {
     case CONNECT_STEP_FIRST:
-
         g_assert (ctx->ipv4 || ctx->ipv6);
-
-        /* Fall down */
         ctx->step++;
+        /* fall through */
 
     case CONNECT_STEP_OPEN_QMI_PORT:
         /* If we're explicitly opening the port (e.g. using a different cdc-wdm
@@ -1309,8 +1336,8 @@ connect_context_step (GTask *task)
             return;
         }
 
-        /* If already open, just fall down */
         ctx->step++;
+        /* fall through */
 
     case CONNECT_STEP_IP_METHOD:
         /* Once the QMI port is open, we decide the IP method we're going
@@ -1322,10 +1349,9 @@ connect_context_step (GTask *task)
         else
             ctx->ip_method = MM_BEARER_IP_METHOD_DHCP;
 
-        mm_dbg ("Defaulting to use %s IP method", mm_bearer_ip_method_get_string (ctx->ip_method));
-
-        /* Just fall down */
+        mm_obj_dbg (self, "defaulting to use %s IP method", mm_bearer_ip_method_get_string (ctx->ip_method));
         ctx->step++;
+        /* fall through */
 
     case CONNECT_STEP_IPV4:
         /* If no IPv4 setup needed, jump to IPv6 */
@@ -1336,11 +1362,11 @@ connect_context_step (GTask *task)
         }
 
         /* Start IPv4 setup */
-        mm_dbg ("Running IPv4 connection setup");
+        mm_obj_dbg (self, "running IPv4 connection setup");
         ctx->running_ipv4 = TRUE;
         ctx->running_ipv6 = FALSE;
-        /* Just fall down */
         ctx->step++;
+        /* fall through */
 
     case CONNECT_STEP_WDS_CLIENT_IPV4: {
         QmiClient *client;
@@ -1349,7 +1375,7 @@ connect_context_step (GTask *task)
                                          QMI_SERVICE_WDS,
                                          MM_PORT_QMI_FLAG_WDS_IPV4);
         if (!client) {
-            mm_dbg ("Allocating IPv4-specific WDS client");
+            mm_obj_dbg (self, "allocating IPv4-specific WDS client");
             mm_port_qmi_allocate_client (ctx->qmi,
                                          QMI_SERVICE_WDS,
                                          MM_PORT_QMI_FLAG_WDS_IPV4,
@@ -1360,9 +1386,8 @@ connect_context_step (GTask *task)
         }
 
         ctx->client_ipv4 = QMI_CLIENT_WDS (client);
-        /* Just fall down */
         ctx->step++;
-    }
+    } /* fall through */
 
     case CONNECT_STEP_IP_FAMILY_IPV4:
         /* If client is new enough, select IP family */
@@ -1370,7 +1395,7 @@ connect_context_step (GTask *task)
             qmi_client_check_version (QMI_CLIENT (ctx->client_ipv4), 1, 9)) {
             QmiMessageWdsSetIpFamilyInput *input;
 
-            mm_dbg ("Setting default IP family to: IPv4");
+            mm_obj_dbg (self, "setting default IP family to: IPv4");
             input = qmi_message_wds_set_ip_family_input_new ();
             qmi_message_wds_set_ip_family_input_set_preference (input, QMI_WDS_IP_FAMILY_IPV4, NULL);
             qmi_client_wds_set_ip_family (ctx->client_ipv4,
@@ -1385,8 +1410,8 @@ connect_context_step (GTask *task)
 
         ctx->default_ip_family_set = FALSE;
 
-        /* Just fall down */
         ctx->step++;
+        /* fall through */
 
     case CONNECT_STEP_ENABLE_INDICATIONS_IPV4:
         common_setup_cleanup_packet_service_status_unsolicited_events (ctx->self,
@@ -1403,7 +1428,7 @@ connect_context_step (GTask *task)
     case CONNECT_STEP_START_NETWORK_IPV4: {
         QmiMessageWdsStartNetworkInput *input;
 
-        mm_dbg ("Starting IPv4 connection...");
+        mm_obj_dbg (self, "starting IPv4 connection...");
         input = build_start_network_input (ctx);
         qmi_client_wds_start_network (ctx->client_ipv4,
                                       input,
@@ -1415,16 +1440,15 @@ connect_context_step (GTask *task)
         return;
     }
 
-    case CONNECT_STEP_GET_CURRENT_SETTINGS_IPV4: {
+    case CONNECT_STEP_GET_CURRENT_SETTINGS_IPV4:
         /* Retrieve and print IP configuration */
         if (ctx->packet_data_handle_ipv4) {
-            mm_dbg ("Getting IPv4 configuration...");
+            mm_obj_dbg (self, "getting IPv4 configuration...");
             get_current_settings (task, ctx->client_ipv4);
             return;
         }
-        /* Fall through */
         ctx->step++;
-    }
+        /* fall through */
 
     case CONNECT_STEP_IPV6:
         /* If no IPv6 setup needed, jump to last */
@@ -1435,11 +1459,11 @@ connect_context_step (GTask *task)
         }
 
         /* Start IPv6 setup */
-        mm_dbg ("Running IPv6 connection setup");
+        mm_obj_dbg (self, "running IPv6 connection setup");
         ctx->running_ipv4 = FALSE;
         ctx->running_ipv6 = TRUE;
-        /* Just fall down */
         ctx->step++;
+        /* fall through */
 
     case CONNECT_STEP_WDS_CLIENT_IPV6: {
         QmiClient *client;
@@ -1448,7 +1472,7 @@ connect_context_step (GTask *task)
                                          QMI_SERVICE_WDS,
                                          MM_PORT_QMI_FLAG_WDS_IPV6);
         if (!client) {
-            mm_dbg ("Allocating IPv6-specific WDS client");
+            mm_obj_dbg (self, "allocating IPv6-specific WDS client");
             mm_port_qmi_allocate_client (ctx->qmi,
                                          QMI_SERVICE_WDS,
                                          MM_PORT_QMI_FLAG_WDS_IPV6,
@@ -1459,9 +1483,8 @@ connect_context_step (GTask *task)
         }
 
         ctx->client_ipv6 = QMI_CLIENT_WDS (client);
-        /* Just fall down */
         ctx->step++;
-    }
+    } /* fall through */
 
     case CONNECT_STEP_IP_FAMILY_IPV6:
 
@@ -1471,7 +1494,7 @@ connect_context_step (GTask *task)
         if (qmi_client_check_version (QMI_CLIENT (ctx->client_ipv6), 1, 9)) {
             QmiMessageWdsSetIpFamilyInput *input;
 
-            mm_dbg ("Setting default IP family to: IPv6");
+            mm_obj_dbg (self, "setting default IP family to: IPv6");
             input = qmi_message_wds_set_ip_family_input_new ();
             qmi_message_wds_set_ip_family_input_set_preference (input, QMI_WDS_IP_FAMILY_IPV6, NULL);
             qmi_client_wds_set_ip_family (ctx->client_ipv6,
@@ -1486,8 +1509,8 @@ connect_context_step (GTask *task)
 
         ctx->default_ip_family_set = FALSE;
 
-        /* Just fall down */
         ctx->step++;
+        /* fall through */
 
     case CONNECT_STEP_ENABLE_INDICATIONS_IPV6:
         common_setup_cleanup_packet_service_status_unsolicited_events (ctx->self,
@@ -1504,7 +1527,7 @@ connect_context_step (GTask *task)
     case CONNECT_STEP_START_NETWORK_IPV6: {
         QmiMessageWdsStartNetworkInput *input;
 
-        mm_dbg ("Starting IPv6 connection...");
+        mm_obj_dbg (self, "starting IPv6 connection...");
         input = build_start_network_input (ctx);
         qmi_client_wds_start_network (ctx->client_ipv6,
                                       input,
@@ -1516,16 +1539,15 @@ connect_context_step (GTask *task)
         return;
     }
 
-    case CONNECT_STEP_GET_CURRENT_SETTINGS_IPV6: {
+    case CONNECT_STEP_GET_CURRENT_SETTINGS_IPV6:
         /* Retrieve and print IP configuration */
         if (ctx->packet_data_handle_ipv6) {
-            mm_dbg ("Getting IPv6 configuration...");
+            mm_obj_dbg (self, "getting IPv6 configuration...");
             get_current_settings (task, ctx->client_ipv6);
             return;
         }
-        /* Fall through */
         ctx->step++;
-    }
+        /* fall through */
 
     case CONNECT_STEP_LAST:
         /* If one of IPv4 or IPv6 succeeds, we're connected */
@@ -1564,6 +1586,7 @@ connect_context_step (GTask *task)
         g_assert (ctx->self->priv->client_ipv4 == NULL);
         if (ctx->packet_data_handle_ipv4) {
             ctx->self->priv->packet_data_handle_ipv4 = ctx->packet_data_handle_ipv4;
+            ctx->packet_data_handle_ipv4 = 0;
             ctx->self->priv->packet_service_status_ipv4_indication_id = ctx->packet_service_status_ipv4_indication_id;
             ctx->packet_service_status_ipv4_indication_id = 0;
             ctx->self->priv->event_report_ipv4_indication_id = ctx->event_report_ipv4_indication_id;
@@ -1575,6 +1598,7 @@ connect_context_step (GTask *task)
         g_assert (ctx->self->priv->client_ipv6 == NULL);
         if (ctx->packet_data_handle_ipv6) {
             ctx->self->priv->packet_data_handle_ipv6 = ctx->packet_data_handle_ipv6;
+            ctx->packet_data_handle_ipv6 = 0;
             ctx->self->priv->packet_service_status_ipv6_indication_id = ctx->packet_service_status_ipv6_indication_id;
             ctx->packet_service_status_ipv6_indication_id = 0;
             ctx->self->priv->event_report_ipv6_indication_id = ctx->event_report_ipv6_indication_id;
@@ -1588,6 +1612,9 @@ connect_context_step (GTask *task)
                                                         ctx->ipv6_config),
                           NULL);
         return;
+
+    default:
+        g_assert_not_reached ();
     }
 }
 
@@ -1675,11 +1702,9 @@ _connect (MMBaseBearer *_self,
         goto out;
     }
 
-    mm_dbg ("Launching connection with QMI port (%s/%s) and data port (%s/%s)",
-            mm_port_subsys_get_string (mm_port_get_subsys (MM_PORT (qmi))),
-            mm_port_get_device (MM_PORT (qmi)),
-            mm_port_subsys_get_string (mm_port_get_subsys (data)),
-            mm_port_get_device (data));
+    mm_obj_dbg (self, "launching connection with QMI port (%s) and data port (%s)",
+                mm_port_get_device (MM_PORT (qmi)),
+                mm_port_get_device (data));
 
     ctx = g_slice_new0 (ConnectContext);
     ctx->self = g_object_ref (self);
@@ -1712,8 +1737,7 @@ _connect (MMBaseBearer *_self,
 
             ip_family = mm_base_bearer_get_default_ip_family (_self);
             ip_family_str = mm_bearer_ip_family_build_string_from_mask (ip_family);
-            mm_dbg ("No specific IP family requested, defaulting to %s",
-                    ip_family_str);
+            mm_obj_dbg (self, "no specific IP family requested, defaulting to %s", ip_family_str);
             ctx->no_ip_family_preference = TRUE;
             g_free (ip_family_str);
         }
@@ -1883,7 +1907,7 @@ reset_bearer_connection (MMBearerQmi *self,
         if (self->priv->qmi) {
             if (self->priv->explicit_qmi_open) {
                 self->priv->explicit_qmi_open = FALSE;
-                mm_port_qmi_close (self->priv->qmi);
+                mm_port_qmi_close (self->priv->qmi, NULL, NULL);
             }
             g_clear_object (&self->priv->qmi);
         }
@@ -1953,8 +1977,8 @@ disconnect_context_step (GTask *task)
 
     switch (ctx->step) {
     case DISCONNECT_STEP_FIRST:
-        /* Fall down */
         ctx->step++;
+        /* fall through */
 
     case DISCONNECT_STEP_STOP_NETWORK_IPV4:
         if (ctx->packet_data_handle_ipv4) {
@@ -1984,8 +2008,8 @@ disconnect_context_step (GTask *task)
             return;
         }
 
-        /* Fall down */
         ctx->step++;
+        /* fall through */
 
     case DISCONNECT_STEP_STOP_NETWORK_IPV6:
         if (ctx->packet_data_handle_ipv6) {
@@ -2015,8 +2039,8 @@ disconnect_context_step (GTask *task)
             return;
         }
 
-        /* Fall down */
         ctx->step++;
+        /* fall through */
 
     case DISCONNECT_STEP_LAST:
         if (!ctx->error_ipv4 && !ctx->error_ipv6)
@@ -2038,6 +2062,9 @@ disconnect_context_step (GTask *task)
 
         g_object_unref (task);
         return;
+
+    default:
+        g_assert_not_reached ();
     }
 }
 
@@ -2056,7 +2083,7 @@ disconnect (MMBaseBearer *_self,
         (!self->priv->client_ipv4 && !self->priv->client_ipv6) ||
         !self->priv->data ||
         !self->priv->qmi) {
-        mm_dbg ("No need to disconnect: QMI bearer is already disconnected");
+        mm_obj_dbg (self, "no need to disconnect: QMI bearer is already disconnected");
         g_task_return_boolean (task, TRUE);
         g_object_unref (task);
         return;
