@@ -23,16 +23,43 @@
 #include "mm-iface-modem-cdma.h"
 #include "mm-base-modem.h"
 #include "mm-modem-helpers.h"
-#include "mm-log.h"
-
-#define REGISTRATION_CHECK_TIMEOUT_SEC 30
+#include "mm-log-object.h"
 
 #define SUBSYSTEM_CDMA1X "cdma1x"
 #define SUBSYSTEM_EVDO "evdo"
 
-#define REGISTRATION_CHECK_CONTEXT_TAG    "cdma-registration-check-context-tag"
+/*****************************************************************************/
+/* Private data context */
 
-static GQuark registration_check_context_quark;
+#define PRIVATE_TAG "iface-modem-cdma-private-tag"
+static GQuark private_quark;
+
+typedef struct {
+    gboolean activation_ongoing;
+} Private;
+
+static void
+private_free (Private *priv)
+{
+    g_slice_free (Private, priv);
+}
+
+static Private *
+get_private (MMIfaceModemCdma *self)
+{
+    Private *priv;
+
+    if (G_UNLIKELY (!private_quark))
+        private_quark = g_quark_from_static_string (PRIVATE_TAG);
+
+    priv = g_object_get_qdata (G_OBJECT (self), private_quark);
+    if (!priv) {
+        priv = g_slice_new0 (Private);
+        g_object_set_qdata_full (G_OBJECT (self), private_quark, priv, (GDestroyNotify)private_free);
+    }
+
+    return priv;
+}
 
 /*****************************************************************************/
 
@@ -91,7 +118,11 @@ handle_activate_ready (MMIfaceModemCdma *self,
                        GAsyncResult *res,
                        HandleActivateContext *ctx)
 {
-    GError *error = NULL;
+    Private *priv;
+    GError  *error = NULL;
+
+    priv = get_private (self);
+    priv->activation_ongoing = FALSE;
 
     if (!MM_IFACE_MODEM_CDMA_GET_INTERFACE (self)->activate_finish (self, res,&error))
         g_dbus_method_invocation_take_error (ctx->invocation, error);
@@ -106,8 +137,11 @@ handle_activate_auth_ready (MMBaseModem *self,
                             GAsyncResult *res,
                             HandleActivateContext *ctx)
 {
-    MMModemState modem_state;
-    GError *error = NULL;
+    Private      *priv;
+    MMModemState  modem_state;
+    GError       *error = NULL;
+
+    priv = get_private (MM_IFACE_MODEM_CDMA (self));
 
     if (!mm_base_modem_authorize_finish (self, res, &error)) {
         g_dbus_method_invocation_take_error (ctx->invocation, error);
@@ -115,9 +149,19 @@ handle_activate_auth_ready (MMBaseModem *self,
         return;
     }
 
+    /* Fail if we have already an activation ongoing */
+    if (priv->activation_ongoing) {
+        g_dbus_method_invocation_return_error (ctx->invocation,
+                                               MM_CORE_ERROR,
+                                               MM_CORE_ERROR_IN_PROGRESS,
+                                               "An activation operation is already in progress");
+        handle_activate_context_free (ctx);
+        return;
+    }
+
     /* If we're already activated, nothing to do */
     if (mm_gdbus_modem_cdma_get_activation_state (ctx->skeleton) == MM_MODEM_CDMA_ACTIVATION_STATE_ACTIVATED) {
-        mm_dbg ("Modem is already activated");
+        mm_obj_dbg (self, "already activated");
         mm_gdbus_modem_cdma_complete_activate (ctx->skeleton, ctx->invocation);
         handle_activate_context_free (ctx);
         return;
@@ -135,6 +179,17 @@ handle_activate_auth_ready (MMBaseModem *self,
         return;
     }
 
+    /* Error if carrier code is empty */
+    if (!ctx->carrier || !ctx->carrier[0]) {
+        g_dbus_method_invocation_return_error (ctx->invocation,
+                                               MM_CORE_ERROR,
+                                               MM_CORE_ERROR_INVALID_ARGS,
+                                               "Cannot perform OTA activation: "
+                                               "invalid empty carrier code");
+        handle_activate_context_free (ctx);
+        return;
+    }
+
     modem_state = MM_MODEM_STATE_UNKNOWN;
     g_object_get (self,
                   MM_IFACE_MODEM_STATE, &modem_state,
@@ -160,6 +215,7 @@ handle_activate_auth_ready (MMBaseModem *self,
     case MM_MODEM_STATE_ENABLED:
     case MM_MODEM_STATE_SEARCHING:
     case MM_MODEM_STATE_REGISTERED:
+        priv->activation_ongoing = TRUE;
         MM_IFACE_MODEM_CDMA_GET_INTERFACE (self)->activate (
             MM_IFACE_MODEM_CDMA (self),
             ctx->carrier,
@@ -193,6 +249,9 @@ handle_activate_auth_ready (MMBaseModem *self,
                                                "Cannot perform OTA activation: "
                                                "modem is connected");
         break;
+
+    default:
+        g_assert_not_reached ();
     }
 
     handle_activate_context_free (ctx);
@@ -245,7 +304,11 @@ handle_activate_manual_ready (MMIfaceModemCdma *self,
                               GAsyncResult *res,
                               HandleActivateManualContext *ctx)
 {
-    GError *error = NULL;
+    Private *priv;
+    GError  *error = NULL;
+
+    priv = get_private (self);
+    priv->activation_ongoing = FALSE;
 
     if (!MM_IFACE_MODEM_CDMA_GET_INTERFACE (self)->activate_manual_finish (self, res,&error))
         g_dbus_method_invocation_take_error (ctx->invocation, error);
@@ -261,8 +324,11 @@ handle_activate_manual_auth_ready (MMBaseModem *self,
                                    HandleActivateManualContext *ctx)
 {
     MMCdmaManualActivationProperties *properties;
-    MMModemState modem_state;
-    GError *error = NULL;
+    Private                          *priv;
+    MMModemState                      modem_state;
+    GError                           *error = NULL;
+
+    priv = get_private (MM_IFACE_MODEM_CDMA (self));
 
     if (!mm_base_modem_authorize_finish (self, res, &error)) {
         g_dbus_method_invocation_take_error (ctx->invocation, error);
@@ -270,9 +336,19 @@ handle_activate_manual_auth_ready (MMBaseModem *self,
         return;
     }
 
+    /* Fail if we have already an activation ongoing */
+    if (priv->activation_ongoing) {
+        g_dbus_method_invocation_return_error (ctx->invocation,
+                                               MM_CORE_ERROR,
+                                               MM_CORE_ERROR_IN_PROGRESS,
+                                               "An activation operation is already in progress");
+        handle_activate_manual_context_free (ctx);
+        return;
+    }
+
     /* If we're already activated, nothing to do */
     if (mm_gdbus_modem_cdma_get_activation_state (ctx->skeleton) == MM_MODEM_CDMA_ACTIVATION_STATE_ACTIVATED) {
-        mm_dbg ("Modem is already activated");
+        mm_obj_dbg (self, "already activated");
         mm_gdbus_modem_cdma_complete_activate_manual (ctx->skeleton, ctx->invocation);
         handle_activate_manual_context_free (ctx);
         return;
@@ -322,6 +398,7 @@ handle_activate_manual_auth_ready (MMBaseModem *self,
     case MM_MODEM_STATE_ENABLED:
     case MM_MODEM_STATE_SEARCHING:
     case MM_MODEM_STATE_REGISTERED:
+        priv->activation_ongoing = TRUE;
         MM_IFACE_MODEM_CDMA_GET_INTERFACE (self)->activate_manual (
             MM_IFACE_MODEM_CDMA (self),
             properties,
@@ -356,6 +433,9 @@ handle_activate_manual_auth_ready (MMBaseModem *self,
                                                "Cannot perform manual activation: "
                                                "modem is connected");
         break;
+
+    default:
+        g_assert_not_reached ();
     }
 
     g_object_unref (properties);
@@ -432,6 +512,11 @@ mm_iface_modem_cdma_register_in_network (MMIfaceModemCdma *self,
 
 /*****************************************************************************/
 
+#define REGISTRATION_CHECK_TIMEOUT_SEC 30
+#define REGISTRATION_CHECK_CONTEXT_TAG "cdma-registration-check-context-tag"
+
+static GQuark registration_check_context_quark;
+
 typedef struct _RunRegistrationChecksContext RunRegistrationChecksContext;
 static void registration_check_step (GTask *task);
 
@@ -532,7 +617,7 @@ get_call_manager_state_ready (MMIfaceModemCdma *self,
             &ctx->call_manager_system_mode,
             &ctx->call_manager_operating_mode,
             &error)) {
-        mm_dbg ("Could not get call manager state: %s", error->message);
+        mm_obj_dbg (self, "could not get call manager state: %s", error->message);
         g_error_free (error);
         /* Fallback to AT-based check */
         ctx->step = REGISTRATION_CHECK_STEP_AT_CDMA_SERVICE_STATUS;
@@ -569,7 +654,7 @@ get_hdr_state_ready (MMIfaceModemCdma *self,
             &ctx->hdr_session_state,
             &ctx->hdr_almp_state,
             &error)) {
-        mm_dbg ("Could not get HDR state: %s", error->message);
+        mm_obj_dbg (self, "could not get HDR state: %s", error->message);
         g_error_free (error);
         /* Fallback to AT-based check */
         ctx->step = REGISTRATION_CHECK_STEP_AT_CDMA_SERVICE_STATUS;
@@ -585,14 +670,16 @@ get_hdr_state_ready (MMIfaceModemCdma *self,
 static void
 parse_qcdm_results (GTask *task)
 {
+    MMIfaceModemCdma             *self;
     RunRegistrationChecksContext *ctx;
 
-    ctx = g_task_get_task_data (task);
+    self = g_task_get_source_object (task);
+    ctx  = g_task_get_task_data (task);
 
-    mm_dbg ("QCDM CM System Mode: %d", ctx->call_manager_system_mode);
-    mm_dbg ("QCDM HDR Hybrid Mode: %d", ctx->hdr_hybrid_mode);
-    mm_dbg ("QCDM HDR Session State: %d", ctx->hdr_session_state);
-    mm_dbg ("QCDM HDR ALMP State: %d", ctx->hdr_almp_state);
+    mm_obj_dbg (self, "QCDM CM System Mode: %d", ctx->call_manager_system_mode);
+    mm_obj_dbg (self, "QCDM HDR Hybrid Mode: %d", ctx->hdr_hybrid_mode);
+    mm_obj_dbg (self, "QCDM HDR Session State: %d", ctx->hdr_session_state);
+    mm_obj_dbg (self, "QCDM HDR ALMP State: %d", ctx->hdr_almp_state);
 
     /* Set QCDM-obtained registration info */
     switch (ctx->call_manager_system_mode) {
@@ -640,7 +727,7 @@ get_service_status_ready (MMIfaceModemCdma *self,
                                                                               res,
                                                                               &has_service,
                                                                               &error)) {
-        mm_warn ("Could not get service status: %s", error->message);
+        mm_obj_warn (self, "could not get service status: %s", error->message);
         g_task_return_error (task, error);
         g_object_unref (task);
         return;
@@ -648,7 +735,7 @@ get_service_status_ready (MMIfaceModemCdma *self,
 
     if (!has_service) {
         /* There is no CDMA service at all, end registration checks */
-        mm_dbg ("No CDMA service found");
+        mm_obj_dbg (self, "no CDMA service found");
         ctx->step = REGISTRATION_CHECK_STEP_LAST;
     } else
         /* If we do have service, go on to next step */
@@ -681,7 +768,7 @@ get_cdma1x_serving_system_ready (MMIfaceModemCdma *self,
         if (!g_error_matches (error,
                               MM_MOBILE_EQUIPMENT_ERROR,
                               MM_MOBILE_EQUIPMENT_ERROR_NO_NETWORK)) {
-            mm_warn ("Could not get serving system: %s", error->message);
+            mm_obj_warn (self, "could not get serving system: %s", error->message);
             g_task_return_error (task, error);
             g_object_unref (task);
             return;
@@ -701,15 +788,17 @@ get_cdma1x_serving_system_ready (MMIfaceModemCdma *self,
 static void
 parse_at_results (GTask *task)
 {
+    MMIfaceModemCdma             *self;
     RunRegistrationChecksContext *ctx;
 
-    ctx = g_task_get_task_data (task);
+    self = g_task_get_source_object (task);
+    ctx  = g_task_get_task_data (task);
 
     /* 99999 means unknown/no service */
     if (ctx->cdma1x_sid == MM_MODEM_CDMA_SID_UNKNOWN &&
         ctx->cdma1x_nid == MM_MODEM_CDMA_NID_UNKNOWN) {
         /* Not registered in CDMA network, end registration checks */
-        mm_dbg ("Not registered in any CDMA network");
+        mm_obj_dbg (self, "no registered in any CDMA network");
         ctx->step = REGISTRATION_CHECK_STEP_LAST;
     } else {
         /* We're registered on the CDMA 1x network (at least) */
@@ -741,7 +830,7 @@ get_detailed_registration_state_ready (MMIfaceModemCdma *self,
             &error)) {
         /* This error is NOT fatal. If we get an error here, we'll just fallback
          * to the non-detailed values we already got. */
-        mm_dbg ("Could not get more detailed registration state: %s", error->message);
+        mm_obj_dbg (self, "could not get more detailed registration state: %s", error->message);
     } else {
         ctx->cdma1x_state = detailed_cdma1x_state;
         ctx->evdo_state = detailed_evdo_state;
@@ -763,8 +852,8 @@ registration_check_step (GTask *task)
 
     switch (ctx->step) {
     case REGISTRATION_CHECK_STEP_FIRST:
-        /* Fall down to next step */
         ctx->step++;
+        /* fall through */
 
     case REGISTRATION_CHECK_STEP_SETUP_REGISTRATION_CHECKS:
         /* Allow implementations to run an initial setup check. This setup allows
@@ -779,11 +868,11 @@ registration_check_step (GTask *task)
                 task);
             return;
         }
-        /* Fall down to next step */
         ctx->step++;
+        /* fall through */
 
     case REGISTRATION_CHECK_STEP_QCDM_CALL_MANAGER_STATE:
-        mm_dbg ("Starting QCDM-based registration checks");
+        mm_obj_dbg (self, "starting QCDM-based registration checks...");
         if (!ctx->skip_qcdm_call_manager_step &&
             MM_IFACE_MODEM_CDMA_GET_INTERFACE (self)->get_call_manager_state &&
             MM_IFACE_MODEM_CDMA_GET_INTERFACE (self)->get_call_manager_state_finish) {
@@ -795,7 +884,7 @@ registration_check_step (GTask *task)
             return;
         }
         /* Fallback to AT-based check */
-        mm_dbg ("  Skipping all QCDM-based checks and falling back to AT-based checks");
+        mm_obj_dbg (self, "  skipping all QCDM-based checks and falling back to AT-based checks");
         ctx->step = REGISTRATION_CHECK_STEP_AT_CDMA_SERVICE_STATUS;
         registration_check_step (task);
         return;
@@ -812,9 +901,9 @@ registration_check_step (GTask *task)
                 task);
             return;
         }
-        mm_dbg ("  Skipping HDR check");
-        /* Fall down to next step */
+        mm_obj_dbg (self, "  skipping HDR check");
         ctx->step++;
+        /* fall through */
 
     case REGISTRATION_CHECK_STEP_QCDM_CDMA1X_SERVING_SYSTEM:
         /* We only care about SID/NID here; nothing to do with registration
@@ -828,9 +917,9 @@ registration_check_step (GTask *task)
                 task);
             return;
         }
-        mm_dbg ("  Skipping CDMA1x Serving System check");
-        /* Fall down to next step */
+        mm_obj_dbg (self, "  skipping CDMA1x serving system check");
         ctx->step++;
+        /* fall through */
 
     case REGISTRATION_CHECK_STEP_QCDM_LAST:
         /* When we get all QCDM results, parse them */
@@ -838,8 +927,7 @@ registration_check_step (GTask *task)
         return;
 
     case REGISTRATION_CHECK_STEP_AT_CDMA_SERVICE_STATUS:
-        mm_dbg ("Starting AT-based registration checks");
-
+        mm_obj_dbg (self, "starting AT-based registration checks");
         /* If we don't have means to get service status, just assume we do have
          * CDMA service and keep on */
         if (!ctx->skip_at_cdma_service_status_step &&
@@ -851,9 +939,9 @@ registration_check_step (GTask *task)
                 task);
             return;
         }
-        mm_dbg ("  Skipping CDMA service status check, assuming with service");
-        /* Fall down to next step */
+        mm_obj_dbg (self, "  skipping CDMA service status check, assuming with service");
         ctx->step++;
+        /* fall through */
 
     case REGISTRATION_CHECK_STEP_AT_CDMA1X_SERVING_SYSTEM:
         /* Now that we have some sort of service, check if the the device is
@@ -875,9 +963,9 @@ registration_check_step (GTask *task)
                 task);
             return;
         }
-        mm_dbg ("  Skipping CDMA1x Serving System check");
-        /* Fall down to next step */
+        mm_obj_dbg (self, "  skipping CDMA1x Serving System check");
         ctx->step++;
+        /* fall through */
 
     case REGISTRATION_CHECK_STEP_AT_LAST:
         /* When we get all AT results, parse them */
@@ -885,7 +973,7 @@ registration_check_step (GTask *task)
         return;
 
     case REGISTRATION_CHECK_STEP_DETAILED_REGISTRATION_STATE:
-        mm_dbg ("Starting detailed registration state check");
+        mm_obj_dbg (self, "starting detailed registration state check");
         /* We let classes implementing this interface to look for more detailed
          * registration info. */
         if (!ctx->skip_detailed_registration_state &&
@@ -903,13 +991,13 @@ registration_check_step (GTask *task)
                 task);
             return;
         }
-        mm_dbg ("  Skipping detailed registration state check");
-        /* Fall down to next step */
+        mm_obj_dbg (self, "  skipping detailed registration state check");
         ctx->step++;
+        /* fall through */
 
     case REGISTRATION_CHECK_STEP_LAST:
         /* We are done without errors! */
-        mm_dbg ("All CDMA registration state checks done");
+        mm_obj_dbg (self, "all CDMA registration state checks done");
         mm_iface_modem_cdma_update_cdma1x_registration_state (self,
                                                               ctx->cdma1x_state,
                                                               ctx->cdma1x_sid,
@@ -920,6 +1008,9 @@ registration_check_step (GTask *task)
         g_task_return_boolean (task, TRUE);
         g_object_unref (task);
         return;
+
+    default:
+        break;
     }
 
     g_assert_not_reached ();
@@ -955,9 +1046,9 @@ mm_iface_modem_cdma_run_registration_checks (MMIfaceModemCdma *self,
                   MM_IFACE_MODEM_CDMA_CDMA1X_NETWORK_SUPPORTED, &cdma1x_supported,
                   NULL);
 
-    mm_dbg ("Running registration checks (CDMA1x: '%s', EV-DO: '%s')",
-            cdma1x_supported ? "yes" : "no",
-            evdo_supported ? "yes" : "no");
+    mm_obj_dbg (self, "running registration checks (CDMA1x: '%s', EV-DO: '%s')",
+                cdma1x_supported ? "yes" : "no",
+                evdo_supported ? "yes" : "no");
 
     if (MM_IFACE_MODEM_CDMA_GET_INTERFACE (self)->run_registration_checks &&
         MM_IFACE_MODEM_CDMA_GET_INTERFACE (self)->run_registration_checks_finish) {
@@ -1069,6 +1160,9 @@ mm_iface_modem_cdma_update_evdo_registration_state (MMIfaceModemCdma *self,
                                                    MM_MODEM_STATE_ENABLED,
                                                    MM_MODEM_STATE_CHANGE_REASON_UNKNOWN);
             break;
+        default:
+            g_assert_not_reached ();
+            break;
         }
     }
 
@@ -1120,6 +1214,9 @@ mm_iface_modem_cdma_update_cdma1x_registration_state (MMIfaceModemCdma *self,
                                                    MM_MODEM_STATE_ENABLED,
                                                    MM_MODEM_STATE_CHANGE_REASON_UNKNOWN);
             break;
+        default:
+            g_assert_not_reached ();
+            break;
         }
     }
 
@@ -1150,7 +1247,7 @@ periodic_registration_checks_ready (MMIfaceModemCdma *self,
 
     mm_iface_modem_cdma_run_registration_checks_finish (self, res, &error);
     if (error) {
-        mm_dbg ("Couldn't refresh CDMA registration status: '%s'", error->message);
+        mm_obj_dbg (self, "couldn't refresh CDMA registration status: %s", error->message);
         g_error_free (error);
     }
 
@@ -1189,7 +1286,7 @@ periodic_registration_check_disable (MMIfaceModemCdma *self)
                         registration_check_context_quark,
                         NULL);
 
-    mm_dbg ("Periodic CDMA registration checks disabled");
+    mm_obj_dbg (self, "periodic CDMA registration checks disabled");
 }
 
 static void
@@ -1208,7 +1305,7 @@ periodic_registration_check_enable (MMIfaceModemCdma *self)
         return;
 
     /* Create context and keep it as object data */
-    mm_dbg ("Periodic CDMA registration checks enabled");
+    mm_obj_dbg (self, "periodic CDMA registration checks enabled");
     ctx = g_new0 (RegistrationCheckContext, 1);
     ctx->timeout_source = g_timeout_add_seconds (REGISTRATION_CHECK_TIMEOUT_SEC,
                                                  (GSourceFunc)periodic_registration_check,
@@ -1245,11 +1342,11 @@ mm_iface_modem_cdma_update_activation_state (MMIfaceModemCdma *self,
         return;
 
     if (activation_error) {
-        mm_dbg ("Activation failed: %s", activation_error->message);
+        mm_obj_dbg (self, "activation failed: %s", activation_error->message);
         if (activation_error->domain == MM_CDMA_ACTIVATION_ERROR)
             error = activation_error->code;
         else {
-            mm_warn ("Error given is not an activation error");
+            mm_obj_warn (self, "error given is not an activation error");
             error = MM_CDMA_ACTIVATION_ERROR_UNKNOWN;
         }
     }
@@ -1312,7 +1409,7 @@ disable_unsolicited_events_ready (MMIfaceModemCdma *self,
 
     MM_IFACE_MODEM_CDMA_GET_INTERFACE (self)->disable_unsolicited_events_finish (self, res, &error);
     if (error) {
-        mm_dbg ("Couldn't disable unsolicited events: '%s'", error->message);
+        mm_obj_dbg (self, "couldn't disable unsolicited events: %s", error->message);
         g_error_free (error);
     }
 
@@ -1332,7 +1429,7 @@ cleanup_unsolicited_events_ready (MMIfaceModemCdma *self,
 
     MM_IFACE_MODEM_CDMA_GET_INTERFACE (self)->cleanup_unsolicited_events_finish (self, res, &error);
     if (error) {
-        mm_dbg ("Couldn't cleanup unsolicited events: '%s'", error->message);
+        mm_obj_dbg (self, "couldn't cleanup unsolicited events: %s", error->message);
         g_error_free (error);
     }
 
@@ -1353,13 +1450,13 @@ interface_disabling_step (GTask *task)
 
     switch (ctx->step) {
     case DISABLING_STEP_FIRST:
-        /* Fall down to next step */
         ctx->step++;
+        /* fall through */
 
     case DISABLING_STEP_PERIODIC_REGISTRATION_CHECKS:
         periodic_registration_check_disable (self);
-        /* Fall down to next step */
         ctx->step++;
+        /* fall through */
 
     case DISABLING_STEP_DISABLE_UNSOLICITED_EVENTS:
         if (MM_IFACE_MODEM_CDMA_GET_INTERFACE (self)->disable_unsolicited_events &&
@@ -1370,8 +1467,8 @@ interface_disabling_step (GTask *task)
                 task);
             return;
         }
-        /* Fall down to next step */
         ctx->step++;
+        /* fall through */
 
     case DISABLING_STEP_CLEANUP_UNSOLICITED_EVENTS:
         if (MM_IFACE_MODEM_CDMA_GET_INTERFACE (self)->cleanup_unsolicited_events &&
@@ -1382,14 +1479,17 @@ interface_disabling_step (GTask *task)
                 task);
             return;
         }
-        /* Fall down to next step */
         ctx->step++;
+        /* fall through */
 
     case DISABLING_STEP_LAST:
         /* We are done without errors! */
         g_task_return_boolean (task, TRUE);
         g_object_unref (task);
         return;
+
+    default:
+        break;
     }
 
     g_assert_not_reached ();
@@ -1470,7 +1570,7 @@ setup_unsolicited_events_ready (MMIfaceModemCdma *self,
     MM_IFACE_MODEM_CDMA_GET_INTERFACE (self)->setup_unsolicited_events_finish (self, res, &error);
     if (error) {
         /* This error shouldn't be treated as critical */
-        mm_dbg ("Setting up unsolicited events failed: '%s'", error->message);
+        mm_obj_dbg (self, "setting up unsolicited events failed: %s", error->message);
         g_error_free (error);
     }
 
@@ -1491,7 +1591,7 @@ enable_unsolicited_events_ready (MMIfaceModemCdma *self,
     MM_IFACE_MODEM_CDMA_GET_INTERFACE (self)->enable_unsolicited_events_finish (self, res, &error);
     if (error) {
         /* This error shouldn't be treated as critical */
-        mm_dbg ("Enabling unsolicited events failed: '%s'", error->message);
+        mm_obj_dbg (self, "enabling unsolicited events failed: %s", error->message);
         g_error_free (error);
     }
 
@@ -1518,8 +1618,8 @@ interface_enabling_step (GTask *task)
 
     switch (ctx->step) {
     case ENABLING_STEP_FIRST:
-        /* Fall down to next step */
         ctx->step++;
+        /* fall through */
 
     case ENABLING_STEP_SETUP_UNSOLICITED_EVENTS:
         if (MM_IFACE_MODEM_CDMA_GET_INTERFACE (self)->setup_unsolicited_events &&
@@ -1530,8 +1630,8 @@ interface_enabling_step (GTask *task)
                 task);
             return;
         }
-        /* Fall down to next step */
         ctx->step++;
+        /* fall through */
 
     case ENABLING_STEP_ENABLE_UNSOLICITED_EVENTS:
         if (MM_IFACE_MODEM_CDMA_GET_INTERFACE (self)->enable_unsolicited_events &&
@@ -1542,19 +1642,22 @@ interface_enabling_step (GTask *task)
                 task);
             return;
         }
-        /* Fall down to next step */
         ctx->step++;
+        /* fall through */
 
     case ENABLING_STEP_PERIODIC_REGISTRATION_CHECKS:
         periodic_registration_check_enable (self);
-        /* Fall down to next step */
         ctx->step++;
+        /* fall through */
 
     case ENABLING_STEP_LAST:
         /* We are done without errors! */
         g_task_return_boolean (task, TRUE);
         g_object_unref (task);
         return;
+
+    default:
+        break;
     }
 
     g_assert_not_reached ();
@@ -1633,7 +1736,7 @@ initialization_context_free (InitializationContext *ctx)
         g_free (val);                                                   \
                                                                         \
         if (error) {                                                    \
-            mm_warn ("couldn't load %s: '%s'", DISPLAY, error->message); \
+            mm_obj_warn (self, "couldn't load %s: %s", DISPLAY, error->message); \
             g_error_free (error);                                       \
         }                                                               \
                                                                         \
@@ -1660,7 +1763,7 @@ load_activation_state_ready (MMIfaceModemCdma *self,
     mm_gdbus_modem_cdma_set_activation_state (ctx->skeleton, state);
 
     if (error) {
-        mm_warn ("couldn't load activation state: '%s'", error->message);
+        mm_obj_warn (self, "couldn't load activation state: %s", error->message);
         g_error_free (error);
     }
 
@@ -1686,8 +1789,8 @@ interface_initialization_step (GTask *task)
 
     switch (ctx->step) {
     case INITIALIZATION_STEP_FIRST:
-        /* Fall down to next step */
         ctx->step++;
+        /* fall through */
 
     case INITIALIZATION_STEP_MEID:
         /* MEID value is meant to be loaded only once during the whole
@@ -1702,8 +1805,8 @@ interface_initialization_step (GTask *task)
                 task);
             return;
         }
-        /* Fall down to next step */
         ctx->step++;
+        /* fall through */
 
     case INITIALIZATION_STEP_ESN:
         /* ESN value is meant to be loaded only once during the whole
@@ -1718,8 +1821,8 @@ interface_initialization_step (GTask *task)
                 task);
             return;
         }
-        /* Fall down to next step */
         ctx->step++;
+        /* fall through */
 
     case INITIALIZATION_STEP_ACTIVATION_STATE:
         /* Initial activation state is meant to be loaded only once during the
@@ -1734,8 +1837,8 @@ interface_initialization_step (GTask *task)
                 task);
             return;
         }
-        /* Fall down to next step */
         ctx->step++;
+        /* fall through */
 
     case INITIALIZATION_STEP_LAST:
         /* We are done without errors! */
@@ -1757,6 +1860,9 @@ interface_initialization_step (GTask *task)
         g_task_return_boolean (task, TRUE);
         g_object_unref (task);
         return;
+
+    default:
+        break;
     }
 
     g_assert_not_reached ();
