@@ -49,6 +49,7 @@ struct _MMSharedQmi {
 };
 
 GType mm_shared_qmi_get_type (void);
+G_DEFINE_AUTOPTR_CLEANUP_FUNC (MMSharedQmi, g_object_unref)
 
 QmiClient *mm_shared_qmi_peek_client   (MMSharedQmi          *self,
                                         QmiService            service,
@@ -147,6 +148,22 @@ void               mm_shared_qmi_factory_reset                      (MMIfaceMode
 gboolean           mm_shared_qmi_factory_reset_finish               (MMIfaceModem         *self,
                                                                      GAsyncResult         *res,
                                                                      GError              **error);
+void               mm_shared_qmi_load_carrier_config                (MMIfaceModem         *self,
+                                                                     GAsyncReadyCallback   callback,
+                                                                     gpointer              user_data);
+gboolean           mm_shared_qmi_load_carrier_config_finish         (MMIfaceModem         *self,
+                                                                     GAsyncResult         *res,
+                                                                     gchar               **carrier_config_name,
+                                                                     gchar               **carrier_config_revision,
+                                                                     GError              **error);
+void               mm_shared_qmi_setup_carrier_config               (MMIfaceModem         *self,
+                                                                     const gchar          *imsi,
+                                                                     const gchar          *carrier_config_mapping,
+                                                                     GAsyncReadyCallback   callback,
+                                                                     gpointer              user_data);
+gboolean           mm_shared_qmi_setup_carrier_config_finish        (MMIfaceModem         *self,
+                                                                     GAsyncResult         *res,
+                                                                     GError              **error);
 
 /* Shared QMI location support */
 
