@@ -846,7 +846,7 @@ read_bearer_data_user_data (MMSmsPart              *sms_part,
         gchar *text;
         guint i;
 
-        SUBPARAMETER_SIZE_CHECK (byte_offset + 1 + ((bit_offset + (num_fields * 7)) / 8));
+        SUBPARAMETER_SIZE_CHECK (byte_offset + ((bit_offset + (num_fields * 7)) / 8));
 
         text = g_malloc (num_fields + 1);
         for (i = 0; i < num_fields; i++) {
@@ -874,7 +874,7 @@ read_bearer_data_user_data (MMSmsPart              *sms_part,
         }
         latin[i] = '\0';
 
-        text = g_convert (latin, -1, "UTF-8", "ISO−8859−1", NULL, NULL, NULL);
+        text = g_convert (latin, -1, "UTF-8", "ISO-8859-1", NULL, NULL, NULL);
         if (!text) {
             mm_obj_dbg (log_object, "            text/data: ignored (latin to UTF-8 conversion error)");
         } else {
